@@ -4,11 +4,10 @@ module RapidDiffs
   module Viewers
     module Text
       class LineNumberComponent < ViewComponent::Base
-        def initialize(line:, line_id:, position:, border: nil)
+        def initialize(line:, line_id:, position:)
           @line = line
           @line_id = line_id
           @position = position
-          @border = border
         end
 
         def line_number
@@ -23,13 +22,6 @@ module RapidDiffs
           'removed' if @line.removed?
         end
 
-        def border_class
-          case @border
-          when :right then 'rd-line-number-border-right'
-          when :both  then 'rd-line-number-border-both'
-          end
-        end
-
         def label
           return s_('RapidDiffs|Removed line %d') % line_number if @line.removed?
           return s_('RapidDiffs|Added line %d') % line_number if @line.added?
