@@ -7,16 +7,17 @@ class Dashboard::SnippetsController < Dashboard::ApplicationController
 
   skip_cross_project_access_check :index
 
-  feature_category :snippets
+  feature_category :source_code_management
 
   def index
     @snippet_counts = Snippets::CountService
       .new(current_user, author: current_user)
       .execute
 
-    @snippets = SnippetsFinder.new(current_user, author: current_user, scope: params[:scope], sort: sort_param)
+    @snippets = SnippetsFinder.new(current_user, organization_id: Current.organization.id, author: current_user,
+      scope: params[:scope], sort: sort_param)
       .execute
-      .page(params[:page])
+      .page(pagination_params[:page])
       .inc_author
       .inc_projects_namespace_route
       .inc_statistics
