@@ -6,10 +6,10 @@ class Groups::BoardsController < Groups::ApplicationController
   include Gitlab::Utils::StrongMemoize
 
   before_action do
-    push_frontend_feature_flag(:board_multi_select, group)
     push_force_frontend_feature_flag(:work_item_tasks_on_boards,
       !!group&.work_item_tasks_on_boards_feature_flag_enabled?)
     push_frontend_feature_flag(:notifications_todos_buttons, current_user)
+    push_frontend_feature_flag(:service_desk_ticket, group)
   end
 
   feature_category :team_planning
