@@ -12,6 +12,7 @@ module Groups
       push_force_frontend_feature_flag(:glql_load_on_click, !!group&.glql_load_on_click_feature_flag_enabled?)
       push_force_frontend_feature_flag(:work_item_planning_view,
         !!group&.work_items_consolidated_list_enabled?(current_user))
+      push_force_frontend_feature_flag(:work_items_saved_views, !!group&.work_items_saved_views_enabled?(current_user))
     end
 
     before_action :handle_new_work_item_path, only: [:show]
@@ -24,12 +25,10 @@ module Groups
 
     urgency :low, [:rss, :calendar]
 
-    def index
-      not_found unless group&.work_items_consolidated_list_enabled?(current_user)
-    end
+    def index; end
 
     def show
-      not_found unless group.supports_group_work_items?
+      not_found unless group.supports_work_items?
 
       @work_item = ::WorkItems::WorkItemsFinder.new(current_user, group_id: group.id)
         .execute.with_work_item_type.find_by_iid(show_params[:iid])
