@@ -38,6 +38,8 @@ class GroupsController < Groups::ApplicationController
   # admin intervention for every affected group. Non-admin users still require step-up auth.
   skip_before_action :enforce_step_up_auth_for_namespace, if: :skip_step_up_auth_for_owner_on_edit_and_update?
 
+  before_action :set_group_markdown_flags
+
   before_action :group_projects, only: [:activity, :merge_requests]
   before_action :event_filter, only: [:activity]
 
@@ -414,7 +416,7 @@ class GroupsController < Groups::ApplicationController
   def redirect_if_epic_params; end
 
   def redirect_issues_to_work_items
-    params = work_items_redirect_params.except("type", "type[]").merge('not[type][]' => 'epic')
+    params = work_items_redirect_params.except("type", "type[]").merge(additional_work_items_params)
 
     redirect_to group_work_items_path(group, params: params)
   end
@@ -423,6 +425,11 @@ class GroupsController < Groups::ApplicationController
     request.query_parameters
   end
 
+  # Overridden in EE
+  def additional_work_items_params
+    {}
+  end
+
   def skip_step_up_auth_for_owner_on_edit_and_update?
     [:edit, :update].include?(action_name.to_sym) && can?(current_user, :admin_group, group)
   end
