@@ -12,11 +12,12 @@ class Projects::CommitsController < Projects::ApplicationController
   prepend_before_action(only: [:show]) { authenticate_sessionless_user!(:rss) }
   around_action :allow_gitaly_ref_name_caching
   before_action :require_non_empty_project
-  before_action :assign_ref_vars, except: :commits_root
   before_action :authorize_read_code!
+  before_action :assign_ref_vars, except: :commits_root
+  before_action :set_is_ambiguous_ref, only: [:show]
   before_action :validate_ref!, except: :commits_root
   before_action :validate_path, if: -> { !request.format.atom? }
-  before_action :set_is_ambiguous_ref, only: [:show]
+  before_action :auth_for_path, except: :commits_root
   before_action :set_commits, except: :commits_root
 
   feature_category :source_code_management
@@ -28,12 +29,10 @@ class Projects::CommitsController < Projects::ApplicationController
 
   # rubocop: disable CodeReuse/ActiveRecord
   def show
-    authenticate_user! if require_auth?
-
     @merge_request = MergeRequestsFinder.new(current_user, project_id: @project.id).execute.opened
       .find_by(source_project: @project, source_branch: @ref, target_branch: @repository.root_ref)
 
-    @ref_type = ref_type
+    @ref_type = ref_type if Feature.disabled?(:verified_ref_extractor, @project)
 
     respond_to do |format|
       format.html
@@ -51,8 +50,6 @@ class Projects::CommitsController < Projects::ApplicationController
   # rubocop: enable CodeReuse/ActiveRecord
 
   def signatures
-    authenticate_user! if require_auth?
-
     respond_to do |format|
       format.json do
         render json: {
@@ -84,6 +81,10 @@ class Projects::CommitsController < Projects::ApplicationController
     current_user.blank? && @path.present? && Feature.enabled?(:require_login_for_commit_tree, @project)
   end
 
+  def auth_for_path
+    authenticate_user! if require_auth?
+  end
+
   def set_commits
     limit = permitted_params[:limit].to_i
     @limit = limit > 0 ? limit : COMMITS_DEFAULT_LIMIT # limit can only ever be a positive number
