@@ -17,7 +17,7 @@ class Projects::CycleAnalyticsController < Projects::ApplicationController
     label: 'redis_hll_counters.analytics.analytics_total_unique_counts_monthly',
     destinations: %i[redis_hll snowplow]
 
-  feature_category :team_planning
+  feature_category :value_stream_management
   urgency :low
 
   before_action do
