@@ -1,8 +1,18 @@
 # frozen_string_literal: true
 
 class Projects::ProtectedBranchesController < Projects::ProtectedRefsController
+  def show
+    super
+
+    render 'protected_branches/show'
+  end
+
   protected
 
+  def ref_type
+    :branches
+  end
+
   def project_refs
     @project.repository.branches
   end
@@ -21,9 +31,9 @@ class Projects::ProtectedBranchesController < Projects::ProtectedRefsController
 
   def protected_ref_params(*attrs)
     attrs = ([:name,
-              :allow_force_push,
-              merge_access_levels_attributes: access_level_attributes,
-              push_access_levels_attributes: access_level_attributes] + attrs).uniq
+      :allow_force_push,
+      { merge_access_levels_attributes: access_level_attributes,
+        push_access_levels_attributes: access_level_attributes }] + attrs).uniq
 
     params.require(:protected_branch).permit(attrs)
   end
