@@ -42,6 +42,8 @@ class ProjectsController < Projects::ApplicationController
   skip_before_action :enforce_step_up_auth_for_namespace, only: [:create]
   before_action :enforce_step_up_auth_for_namespace_on_create, only: [:create]
 
+  before_action :set_project_markdown_flags
+
   # Project Export Rate Limit
   before_action :check_export_rate_limit!, only: [:export, :download_export, :generate_new_export]
 
@@ -53,14 +55,15 @@ class ProjectsController < Projects::ApplicationController
     # TODO: We need to remove the FF eventually when we rollout page_specific_styles
     push_frontend_feature_flag(:page_specific_styles, current_user)
     push_licensed_feature(:file_locks) if @project.present? && @project.licensed_feature_available?(:file_locks)
-    push_frontend_feature_flag(:directory_code_dropdown_updates, current_user)
-    push_frontend_feature_flag(:repository_file_tree_browser, @project)
+    push_frontend_feature_flag(:repository_file_tree_browser, current_user)
 
     if @project.present? && @project.licensed_feature_available?(:security_orchestration_policies)
       push_licensed_feature(:security_orchestration_policies)
     end
   end
 
+  before_action :push_work_item_planning_view_feature_flag, only: [:edit]
+
   layout :determine_layout
 
   feature_category :groups_and_projects, [
@@ -294,7 +297,7 @@ class ProjectsController < Projects::ApplicationController
       edit_project_path(@project, anchor: 'js-project-advanced-settings'),
       notice: _("Project export started. A download link will be sent by email and made available on this page.")
     )
-  rescue Project::ExportLimitExceeded => e
+  rescue Project::ExportLimitExceeded, Project::ExportAlreadyInProgress => e
     redirect_to(
       edit_project_path(@project, anchor: 'js-project-advanced-settings'),
       alert: e.to_s
@@ -659,6 +662,10 @@ class ProjectsController < Projects::ApplicationController
     namespace_id = params.dig(:project, :namespace_id)
     enforce_step_up_auth_for_namespace_id(namespace_id)
   end
+
+  def push_work_item_planning_view_feature_flag
+    push_force_frontend_feature_flag(:work_item_planning_view, !!@project.work_items_consolidated_list_enabled?(current_user))
+  end
 end
 
 ProjectsController.prepend_mod_with('ProjectsController')
