@@ -50,9 +50,11 @@ module Ci
     end
 
     def find_from_database_token
-      partition_id = ::Ci::Builds::TokenPrefix.decode_partition(token)
-      job = ::Ci::Build.in_partition(partition_id).find_by_token(token) if partition_id.present?
-      return job if job
+      if Feature.disabled?(:ci_build_find_token_authenticatable, Feature.current_request)
+        partition_id = ::Ci::Builds::TokenPrefix.decode_partition(token)
+        job = ::Ci::Build.in_partition(partition_id).find_by_token(token) if partition_id.present?
+        return job if job
+      end
 
       ::Ci::Build.find_by_token(token)
     end
@@ -68,8 +70,6 @@ module Ci
     end
 
     def validate_executing_job!(job)
-      return if job.runner_ack_wait_status == :waiting
-
       raise NotRunningJobError, 'Job is not running' unless Ci::HasStatus::EXECUTING_STATUSES.include?(job.status)
     end
 
