@@ -15,12 +15,15 @@ module Mutations
       authorize :create_work_item
 
       MUTUALLY_EXCLUSIVE_ARGUMENTS_ERROR = 'Please provide either projectPath or namespacePath argument, but not both.'
-      DISABLED_FF_ERROR = 'create_group_level_work_items feature flag is disabled. Only project paths allowed.'
 
       def self.authorization_scopes
         super + [:ai_workflows]
       end
 
+      argument :create_source,
+        GraphQL::Types::String,
+        required: false,
+        description: 'Source which triggered the creation of the work item. Used only for tracking purposes.'
       argument :created_at, Types::TimeType,
         required: false,
         description: 'Timestamp when the work item was created. Available only for admins and project owners.'
@@ -94,6 +97,8 @@ module Mutations
       end
 
       def resolve(project_path: nil, namespace_path: nil, **attributes)
+        Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/578961')
+
         container_path = project_path || namespace_path
         container = authorized_find!(container_path)
         params = params_with_work_item_type(attributes).merge(author_id: current_user.id,
@@ -122,6 +127,7 @@ module Mutations
 
       private
 
+      # Overridden on EE
       def check_feature_available!(container, type, params)
         return unless container.is_a?(::Group)
 
@@ -130,9 +136,9 @@ module Mutations
             _('Only project level work items can be created to resolve noteable discussions')
         end
 
-        return if ::WorkItems::Type.allowed_group_level_types(container).include?(type.base_type)
+        return if container.allowed_work_item_type?(type.base_type)
 
-        raise_feature_not_available_error!(type)
+        raise_resource_not_available_error!
       end
 
       def params_with_resolve_discussion_params(attributes)
@@ -145,7 +151,12 @@ module Mutations
             _('Only Merge Requests are allowed as a noteable to resolve discussions of at the moment.')
         end
 
-        raise_resource_not_available_error! unless current_user.can?(:resolve_note, noteable)
+        if discussion_attributes[:discussion_id].present?
+          discussion = noteable.find_discussion(discussion_attributes[:discussion_id])
+          raise_resource_not_available_error! unless discussion&.can_resolve?(current_user)
+        else
+          raise_resource_not_available_error! unless noteable.discussions_can_be_resolved_by?(current_user)
+        end
 
         attributes[:discussion_to_resolve] = discussion_attributes[:discussion_id]
         attributes[:merge_request_to_resolve_discussions_object] = noteable
@@ -160,11 +171,6 @@ module Mutations
 
         attributes
       end
-
-      # type is used in overridden EE method
-      def raise_feature_not_available_error!(_type)
-        raise Gitlab::Graphql::Errors::ArgumentError, DISABLED_FF_ERROR
-      end
     end
   end
 end
