@@ -34,7 +34,7 @@ module Resolvers
     # We fetch blobs from Gitaly efficiently but it still scales O(N) with the
     # number of paths being fetched, so apply a scaling limit to that.
     def self.resolver_complexity(args, child_complexity:)
-      super + args[:paths].size
+      super + args.fetch(:paths, []).size
     end
 
     private
@@ -42,7 +42,7 @@ module Resolvers
     def resolve_with_lookahead(paths:, ref:, ref_type:)
       authorize!(repository.container)
 
-      return [] if repository.empty?
+      return [] if paths.empty? || repository.empty?
 
       ref ||= repository.root_ref
       validate_ref!(ref)
