@@ -23,12 +23,8 @@ module Types
           null: true,
           description: 'List of permissions of a granular scope.'
 
-        def access
-          'personal_projects'
-        end
-
         def permissions
-          object.permissions.filter_map { |permission_name| ::Authz::Permission.get(permission_name) }
+          object.permissions.filter_map { |permission_name| ::Authz::PermissionGroups::Assignable.get(permission_name) }
         end
       end
       # rubocop:enable Graphql/AuthorizeTypes
