@@ -29,11 +29,20 @@ module Types
           null: false,
           description: 'Resource of the permission.'
 
+        field :resource_name,
+          GraphQL::Types::String,
+          null: true,
+          description: 'Display name of the resource.'
+
+        field :resource_description, # rubocop: disable GraphQL/ExtractType -- no value for now
+          GraphQL::Types::String,
+          null: true,
+          description: 'Description of the resource.'
+
         field :category,
           GraphQL::Types::String,
           null: false,
-          description: 'Permission category.',
-          method: :feature_category
+          description: 'Permission category.'
 
         field :boundaries,
           [Types::Authz::AccessTokens::BoundaryEnum],
