@@ -9,15 +9,23 @@ module Types
 
       PERCENTILES = ::Ci::CollectPipelineAnalyticsServiceBase::ALLOWED_PERCENTILES
 
+      field :mean, Types::DurationType,
+        null: true, description: 'Mean (average) duration.',
+        experiment: { milestone: '18.7' }
+
       PERCENTILES.each do |p|
-        field "p#{p}", Types::DurationType,
+        field :"p#{p}", Types::DurationType,
           null: true, description: "#{p}th percentile. #{p}% of the durations are lower than this value.",
           experiment: { milestone: '15.8' }
 
-        define_method(:"p#{p}") do
-          object[:"p#{p}"]
+        define_method :"p#{p}" do
+          object[:"p#{p}"] || object[:"p#{p}_duration"]
         end
       end
+
+      def mean
+        object[:mean] || object[:mean_duration]
+      end
     end
     # rubocop: enable Graphql/AuthorizeTypes
   end
