@@ -41,16 +41,12 @@ module Types
           null: true,
           description: 'Regular expression pattern that the input value must match if provided.'
 
-        field :rules, [Types::Ci::Inputs::RuleType],
+        field :rules, [Types::Ci::Inputs::RuleType], # rubocop:disable GraphQL/FieldHashKey -- field requires custom method
           null: true,
-          experiment: { milestone: '18.6' },
           description: 'Conditional rules for dynamic input options.'
 
         def rules
-          return unless Feature.enabled?(:ci_dynamic_pipeline_inputs, context[:project])
-          return unless object.respond_to?(:rules)
-
-          object.rules
+          object[:rules]
         end
       end
     end
