@@ -151,7 +151,7 @@ module Types
       resolver: Resolvers::Import::SourceUsersResolver,
       description: 'Import source users of the namespace. This field can only be resolved for one namespace in any ' \
         'single request.' do
-      extension(::Gitlab::Graphql::Limit::FieldCallCount, limit: 1)
+      extension(::Gitlab::Graphql::Limit::FieldCallCount, limit: 2)
     end
 
     field :sidebar,
@@ -175,6 +175,15 @@ module Types
       method: :itself,
       experiment: { milestone: '18.1' }
 
+    field :metadata,
+      Types::Namespaces::Metadata,
+      null: true,
+      description: 'Metadata information for the namespace.',
+      method: :itself,
+      experiment: { milestone: '18.6' } do
+      extension(::Gitlab::Graphql::Limit::FieldCallCount, limit: 2)
+    end
+
     field :markdown_paths,
       Types::Namespaces::MarkdownPaths,
       null: true,
@@ -209,6 +218,27 @@ module Types
       scopes: [:api, :read_api, :ai_workflows],
       description: 'URL of the namespace.'
 
+    field :saved_views,
+      null: true,
+      scopes: [:api, :read_api],
+      description: 'Saved views associated with the namespace.',
+      experiment: { milestone: '18.7' },
+      resolver: ::Resolvers::WorkItems::SavedViews::SavedViewsResolver
+
+    field :subscribed_saved_view_limit,
+      GraphQL::Types::Int,
+      null: false,
+      scopes: [:api, :read_api],
+      description: 'Maximum number of subscribed saved views allowed on the namespace.',
+      experiment: { milestone: '18.8' },
+      method: :itself
+
+    field :root_namespace, 'Types::NamespaceType',
+      null: false,
+      method: :root_ancestor,
+      scopes: [:api, :read_api, :ai_workflows],
+      description: 'Top-level namespace of the namespace.'
+
     markdown_field :description_html, null: true, &:namespace_details
 
     def achievements_path
@@ -234,6 +264,10 @@ module Types
     def root_storage_statistics
       Gitlab::Graphql::Loaders::BatchRootStorageStatisticsLoader.new(object.id).find
     end
+
+    def subscribed_saved_view_limit
+      ::WorkItems::SavedViews::UserSavedView.user_saved_view_limit(object)
+    end
   end
 end
 
