@@ -23,6 +23,16 @@ module Types
           complexity: 5,
           description: 'Allowed parent types for the work item type.'
 
+        field :propagates_milestone, GraphQL::Types::Boolean,
+          null: true,
+          description: 'Indicates whether the hierarchy widget propagates milestone.',
+          experiment: { milestone: '18.8' }
+
+        field :auto_expand_tree_on_move, GraphQL::Types::Boolean,
+          null: true,
+          description: 'Indicates whether the hierarchy widget should auto expand the tree during move operation.',
+          experiment: { milestone: '18.8' }
+
         def allowed_child_types(parent:)
           parent.allowed_child_types(authorize: true, resource_parent: context[:resource_parent])
         end
@@ -30,6 +40,14 @@ module Types
         def allowed_parent_types(parent:)
           parent.allowed_parent_types(authorize: true, resource_parent: context[:resource_parent])
         end
+
+        def propagates_milestone
+          object.widget_options&.dig(object.widget_type.to_sym, :propagates_milestone)
+        end
+
+        def auto_expand_tree_on_move
+          object.widget_options&.dig(object.widget_type.to_sym, :auto_expand_tree_on_move)
+        end
       end
       # rubocop:enable Graphql/AuthorizeTypes
       # rubocop:enable GraphQL/ExtractType
