@@ -131,12 +131,8 @@ module ApplicationHelper
     sanitize(str, tags: %w[a span])
   end
 
-  def project_studio_available?
-    Users::ProjectStudio.new(current_user).available?
-  end
-
   def project_studio_enabled?
-    Users::ProjectStudio.new(current_user).enabled?
+    true
   end
 
   def body_data
@@ -145,7 +141,6 @@ module ApplicationHelper
       page_type_id: controller.params[:id],
       group: @group&.path,
       group_full_path: @group&.full_path,
-      project_studio_available: project_studio_available?.to_s,
       project_studio_enabled: project_studio_enabled?.to_s
     }.merge(project_data)
   end
@@ -239,6 +234,10 @@ module ApplicationHelper
     'https://forum.gitlab.com'
   end
 
+  def university_url
+    'https://university.gitlab.com'
+  end
+
   # Convenient method for Rails helper
   def community_forum
     ApplicationHelper.community_forum
