@@ -2,7 +2,9 @@
 
 module LicenseHelper
   def self_managed_new_trial_url
-    subscription_portal_new_trial_url(return_to: CGI.escape(Gitlab.config.gitlab.url))
+    subscription_portal_new_trial_url(
+      return_to: general_admin_application_settings_url(anchor: 'js-add-license-toggle')
+    )
   end
 end
 
