@@ -80,12 +80,10 @@ module Namespaces
 
     def delete_delayed_namespace_message(namespace)
       messages = {
-        group: _('This action will place this group, including its subgroups and projects, ' \
-          'in a pending deletion state for %{deletion_adjourned_period} days, ' \
-          'and delete it permanently on %{date}.'),
-        project: _('This action will place this project, including all its resources, ' \
-          'in a pending deletion state for %{deletion_adjourned_period} days, ' \
-          'and delete it permanently on %{date}.')
+        group: _('This action will permanently delete this group, including its subgroups and projects, ' \
+          'on %{date}. Scheduled pipelines will not run during deletion.'),
+        project: _('This action will permanently delete this project, including all its resources, ' \
+          'on %{date}. Scheduled pipelines will not run during deletion.')
       }
 
       safe_format(
@@ -120,7 +118,8 @@ module Namespaces
       remove_form_id: nil,
       permanently_remove: false,
       button_text: nil,
-      has_security_policy_project: false)
+      has_security_policy_project: false
+    )
       {
         remove_form_id: remove_form_id,
         button_text: button_text.nil? ? _('Delete') : button_text,
@@ -128,7 +127,14 @@ module Namespaces
         disabled: (group.linked_to_subscription? || has_security_policy_project).to_s,
         confirm_danger_message: confirm_remove_group_message(group, permanently_remove),
         phrase: group.full_path,
-        html_confirmation_message: 'true'
+        html_confirmation_message: 'true',
+        form_path: group_path(group),
+        confirm_phrase: group.full_path,
+        full_name: group.full_name,
+        subgroups_count: group.subgroup_count,
+        projects_count: group.project_count,
+        marked_for_deletion: group.scheduled_for_deletion_in_hierarchy_chain?.to_s,
+        permanent_deletion_date: permanent_deletion_date_formatted
       }
     end
 
@@ -136,8 +142,9 @@ module Namespaces
       return _permanently_delete_group_message(group) if permanently_remove || group.self_deletion_scheduled?
 
       safe_format(
-        _("The contents of this group, its subgroups and projects will be permanently deleted after " \
-          "%{deletion_adjourned_period} days on %{date}. After this point, your data cannot be recovered."),
+        _("This group and its contents, including subgroups and projects, will be permanently deleted on %{date}. " \
+          "After this point, your data cannot be recovered. " \
+          "Scheduled pipelines will not run during deletion."),
         deletion_adjourned_period: group.deletion_adjourned_period,
         date: tag.strong(permanent_deletion_date_formatted)
       )
