@@ -462,7 +462,7 @@ module ProjectsHelper
       pagesAccessControlEnabled: Gitlab.config.pages.access_control,
       pagesAccessControlForced: project.pages_access_control_forced_by_ancestor?,
       pagesHelpPath: help_page_path('user/project/pages/pages_access_control.md'),
-      issuesHelpPath: help_page_path('user/project/issues/_index.md'),
+      issuesHelpPath: issues_help_page_path(project),
       membersPagePath: project_project_members_path(project),
       environmentsHelpPath: help_page_path('ci/environments/_index.md'),
       featureFlagsHelpPath: help_page_path('operations/feature_flags.md'),
@@ -557,7 +557,6 @@ module ProjectsHelper
       admin_path: admin_path,
       can_read_project: can?(current_user, :read_project, project).to_s,
       cicd_catalog_path: cicd_catalog_path,
-      is_project_archived: project.archived.to_s,
       is_project_empty: project.empty_repo?.to_s,
       is_project_marked_for_deletion: project.self_deletion_scheduled?.to_s,
       project_avatar: project.avatar_url,
@@ -579,14 +578,14 @@ module ProjectsHelper
   def archiving_available?(project)
     return false unless project
 
-    project.persisted? && !project.self_deletion_scheduled? && can?(current_user, :archive_project, project)
+    project.persisted? && can?(current_user, :archive_project, project)
   end
 
   def show_inactive_project_deletion_banner?(project)
     return false unless project
     return false unless delete_inactive_projects?
 
-    project.persisted? && project.inactive?
+    project.persisted? && project.dormant?
   end
 
   def inactive_project_deletion_date(project)
@@ -743,6 +742,7 @@ module ProjectsHelper
       resource_type: 'project',
       resource_id: project.id,
       resource_path: project_path(project),
+      marked_for_deletion: project.scheduled_for_deletion_in_hierarchy_chain?.to_s,
       help_path: help_page_path('user/project/working_with_projects.md', anchor: 'archive-a-project')
     }
   end
@@ -763,6 +763,14 @@ module ProjectsHelper
 
   private
 
+  def issues_help_page_path(project)
+    if project.work_items_consolidated_list_enabled?(current_user)
+      help_page_path('user/work_items/_index.md')
+    else
+      help_page_path('user/project/issues/_index.md')
+    end
+  end
+
   def can_admin_project_clusters?(project)
     project.clusters.any? && can?(current_user, :admin_cluster, project)
   end
@@ -1035,6 +1043,16 @@ module ProjectsHelper
         :duo_remote_flows_enabled,
         project,
         method(:edit_group_path)
+      ),
+      duo_foundational_flows_cascading_settings: project_cascading_namespace_settings_tooltip_data(
+        :duo_foundational_flows_enabled,
+        project,
+        method(:edit_group_path)
+      ),
+      duo_sast_fp_detection_cascading_settings: project_cascading_namespace_settings_tooltip_data(
+        :duo_sast_fp_detection_enabled,
+        project,
+        method(:edit_group_path)
       )
     }
   end
