@@ -42,6 +42,11 @@ class DeviseMailerPreview < ActionMailer::Preview
   private
 
   def unsaved_user
-    User.new(name: 'Jane Doe', email: 'jdoe@example.com', created_at: 1.minute.ago)
+    User.new(
+      name: 'Jane Doe',
+      email: 'jdoe@example.com',
+      created_at: 1.minute.ago,
+      organization: Organizations::Organization.first # rubocop:disable Gitlab/PreventOrganizationFirst -- mailer previews only
+    )
   end
 end
