@@ -48,6 +48,13 @@ module Ci
 
     belongs_to :resource_group, class_name: 'Ci::ResourceGroup', inverse_of: :processables
 
+    has_one :job_source,
+      ->(job) { in_partition(job) },
+      class_name: 'Ci::BuildSource',
+      foreign_key: :build_id,
+      inverse_of: :job,
+      partition_foreign_key: :partition_id
+
     accepts_nested_attributes_for :needs
     accepts_nested_attributes_for :job_definition_instance
 
@@ -340,6 +347,11 @@ module Ci
       redis_state.enqueue_immediately = true
     end
 
+    def source
+      job_source&.source || pipeline.source
+    end
+    strong_memoize_attr :source
+
     private
 
     def dependencies
