@@ -10,7 +10,6 @@ module Ci
     include TokenAuthenticatable
     include FeatureGate
     include Gitlab::Utils::StrongMemoize
-    include TaggableQueries
     include Presentable
     include EachBatch
     include Ci::HasRunnerStatus
@@ -20,8 +19,6 @@ module Ci
 
     self.primary_key = :id
 
-    ignore_column :sharding_key_id, remove_with: '18.6', remove_after: '2025-10-21'
-
     add_authentication_token_field :token,
       encrypted: :required,
       expires_at: :compute_token_expiration,
@@ -326,6 +323,13 @@ module Ci
       end
     end
 
+    def self.arel_tag_names_array
+      taggings_join_model
+        .scoped_taggables
+        .joins(:tag)
+        .select('COALESCE(array_agg(tags.name ORDER BY tags.name), ARRAY[]::text[])')
+    end
+
     def self.runner_matchers
       unique_params = [
         :runner_type,
@@ -355,6 +359,10 @@ module Ci
       ::Ci::RunnerTagging
     end
 
+    def self.created_runner_prefix
+      ::Authn::TokenField::PrefixHelper.prepend_instance_prefix(CREATED_RUNNER_TOKEN_PREFIX)
+    end
+
     def runner_matcher
       Gitlab::Ci::Matching::RunnerMatcher.new({
         runner_ids: [id],
@@ -444,10 +452,16 @@ module Ci
       return unless token
 
       # We want to show the first characters of the hash, so we need to bypass any fixed components of the token, such
-      # as CREATED_RUNNER_TOKEN_PREFIX, REGISTRATION_RUNNER_TOKEN_PREFIX or legacy_partition_id_prefix_in_16_bit_encode
+      # as instance_prefix, CREATED_RUNNER_TOKEN_PREFIX, REGISTRATION_RUNNER_TOKEN_PREFIX or legacy_partition_id_prefix_in_16_bit_encode
+
       legacy_partition_prefix = legacy_partition_id_prefix_in_16_bit_encode
       start_index = if authenticated_user_registration_type?
-                      CREATED_RUNNER_TOKEN_PREFIX.length
+                      instance_prefix = ::Authn::TokenField::PrefixHelper.instance_prefix
+                      if instance_prefix.present? && token.starts_with?(instance_prefix)
+                        CREATED_RUNNER_TOKEN_PREFIX.length + "#{instance_prefix}-".length
+                      else
+                        CREATED_RUNNER_TOKEN_PREFIX.length
+                      end
                     elsif token.start_with?(REGISTRATION_RUNNER_TOKEN_PREFIX)
                       REGISTRATION_RUNNER_TOKEN_PREFIX.length
                     else
@@ -463,6 +477,10 @@ module Ci
       tag_list.any?
     end
 
+    def tagging_tag_ids
+      taggings.pluck(:tag_id)
+    end
+
     def predefined_variables
       Gitlab::Ci::Variables::Collection.new
         .append(key: 'CI_RUNNER_ID', value: id.to_s)
@@ -666,7 +684,7 @@ module Ci
     def prefix_for_new_and_legacy_runner
       return REGISTRATION_RUNNER_TOKEN_PREFIX if registration_token_registration_type?
 
-      CREATED_RUNNER_TOKEN_PREFIX
+      self.class.created_runner_prefix
     end
 
     def memoize_owner
