@@ -19,14 +19,14 @@ module Editable
 
   def editable_ghost_author
     @editable_ghost_author ||= if respond_to?(:organization_id)
-                                 Users::Internal.for_organization(organization_id).ghost
+                                 Users::Internal.in_organization(organization_id).ghost
                                elsif author.present?
-                                 Users::Internal.for_organization(author.organization_id).ghost
+                                 Users::Internal.in_organization(author.organization_id).ghost
                                else
                                  Gitlab::AppLogger.warn(
                                    "Fallback ghost user used for Editable #{self.class.name}=#{id}"
                                  )
-                                 Users::Internal.for_organization(Organizations::Organization.first).ghost # rubocop:disable Gitlab/PreventOrganizationFirst -- final fallback after all other methods fail
+                                 Users::Internal.in_organization(Organizations::Organization.first).ghost # rubocop:disable Gitlab/PreventOrganizationFirst -- final fallback after all other methods fail
                                end
   end
 end
