@@ -51,6 +51,12 @@ module Enums # rubocop:disable Gitlab/BoundedContexts -- Existing module
       dependency_scanning: 4
     }.freeze
 
+    SCAN_PROFILE_TRIGGER_TYPES = {
+      default_branch_pipeline: 0,
+      merge_request_pipeline: 1,
+      git_push_event: 2
+    }.freeze
+
     DEFAULT_CONFIGURATION_SOURCE = :sbom
 
     CONFIGURATION_SOURCE_TYPES = {
@@ -94,5 +100,9 @@ module Enums # rubocop:disable Gitlab/BoundedContexts -- Existing module
     def self.scan_profile_types
       SCAN_PROFILES_TYPES
     end
+
+    def self.scan_profile_trigger_types
+      SCAN_PROFILE_TRIGGER_TYPES
+    end
   end
 end
