@@ -4,8 +4,8 @@ module IdInOrdered
   extend ActiveSupport::Concern
 
   included do
-    scope :id_in_ordered, -> (ids) do
-      raise ArgumentError, "ids must be an array of integers" unless ids.is_a?(Enumerable) && ids.all? { |id| id.is_a?(Integer) }
+    scope :id_in_ordered, ->(ids) do
+      raise ArgumentError, "ids must be an array of integers" unless ids.is_a?(Enumerable) && ids.all?(Integer)
 
       # No need to sort if no more than 1 and the sorting code doesn't work
       # with an empty array
