@@ -26,13 +26,21 @@ module RedisCacheable
   end
 
   def cache_attributes(values)
-    Gitlab::Redis::Cache.with do |redis|
-      redis.set(cache_attribute_key, values.to_json, ex: CACHED_ATTRIBUTES_EXPIRY_TIME)
+    with_redis do |redis|
+      redis.set(cache_attribute_key, Gitlab::Json.dump(values), ex: CACHED_ATTRIBUTES_EXPIRY_TIME)
     end
 
     clear_memoization(:cached_attributes)
   end
 
+  def merge_cache_attributes(values)
+    existing_attributes = Hash(cached_attributes)
+    merged_attributes = existing_attributes.merge(values.symbolize_keys)
+    return if merged_attributes == existing_attributes
+
+    cache_attributes(merged_attributes)
+  end
+
   private
 
   def cache_attribute_key
@@ -41,13 +49,17 @@ module RedisCacheable
 
   def cached_attributes
     strong_memoize(:cached_attributes) do
-      Gitlab::Redis::Cache.with do |redis|
+      with_redis do |redis|
         data = redis.get(cache_attribute_key)
         Gitlab::Json.parse(data, symbolize_names: true) if data
       end
     end
   end
 
+  def with_redis(&block)
+    Gitlab::Redis::Cache.with(&block)
+  end
+
   def cast_value_from_cache(attribute, value)
     self.class.type_for_attribute(attribute.to_s).cast(value)
   end
