@@ -8,7 +8,6 @@ module ContainerRegistry
     ALLOWED_ACTIONS = %w[push delete].freeze
     PUSH_ACTION = 'push'
     DELETE_ACTION = 'delete'
-    EVENT_TRACKING_CATEGORY = 'container_registry:notification'
     EVENT_PREFIX = 'i_container_registry'
 
     ALLOWED_ACTOR_TYPES = %w[
@@ -47,21 +46,20 @@ module ContainerRegistry
         tracking_action = "create_repository"
       end
 
-      ::Gitlab::Tracking.event(EVENT_TRACKING_CATEGORY, tracking_action)
+      context = { project: project, namespace: project&.namespace }
+      context[:user] = originator if originator.is_a?(User)
 
       if manifest_delete_event?
-        track_internal_event("delete_manifest_from_container_registry", project: project)
+        track_internal_event("delete_manifest_from_container_registry", context)
       else
         event = usage_data_event_for(tracking_action)
         return unless event
 
-        event_attributes = if origin_class == DeployToken
-                             { additional_properties: { property: originator.id.to_s } }
-                           elsif origin_class == User
-                             { user: originator }
-                           end
+        if originator.is_a?(DeployToken)
+          context[:additional_properties] = { property: originator.id.to_s }
+        end
 
-        track_internal_event(event, event_attributes)
+        track_internal_event(event, context)
       end
     end
 
