@@ -7,7 +7,10 @@ module DiffViewer
     included do
       self.type = :simple
       self.switcher_icon = 'code'
-      self.switcher_title = _('source diff')
+
+      def self.switcher_title
+        _('source diff')
+      end
     end
   end
 end
