@@ -206,8 +206,4 @@ class Discussion
   def noteable_collection_name
     noteable.class.underscore.pluralize
   end
-
-  def can_resolve_discussion?(user)
-    resolvable? && !!user&.can?(:resolve_note, first_note)
-  end
 end
