@@ -5,6 +5,11 @@ class GpgKey < ApplicationRecord
   KEY_SUFFIX = '-----END PGP PUBLIC KEY BLOCK-----'
 
   include ShaAttribute
+  include Cells::Claimable
+
+  cells_claims_attribute :key, type: CLAIMS_BUCKET_TYPE::GPG_KEYS
+
+  cells_claims_metadata subject_type: CLAIMS_SUBJECT_TYPE::USER, subject_key: :user_id
 
   sha_attribute :primary_keyid
   sha_attribute :fingerprint
@@ -124,6 +129,10 @@ class GpgKey < ApplicationRecord
       subkeys.create!(keyid: subkey_data[:keyid], fingerprint: subkey_data[:fingerprint])
     end
   end
+
+  def unique_attribute
+    :key
+  end
 end
 
 GpgKey.prepend_mod_with('GpgKey')
