@@ -6,6 +6,7 @@ class Group < Namespace
   include Gitlab::ConfigHelper
   include AfterCommitQueue
   include AccessRequestable
+  include Authz::HasRoles
   include Avatarable
   include SelectForProjectAuthorization
   include LoadedInGroupList
@@ -145,6 +146,7 @@ class Group < Namespace
   scope :self_or_ancestors_aimed_for_deletion, -> { where(self_or_ancestors_deletion_schedule_subquery.exists) }
 
   scope :not_aimed_for_deletion, -> { where.missing(:deletion_schedule) }
+  scope :self_not_aimed_for_deletion, -> { where.missing(:deletion_schedule) }
   scope :self_and_ancestors_not_aimed_for_deletion, -> { where.not(self_or_ancestors_deletion_schedule_subquery.exists) }
 
   scope :with_deletion_schedule, -> { preload(deletion_schedule: :deleting_user) }
@@ -247,16 +249,24 @@ class Group < Namespace
 
   scope :with_users, -> { includes(:users) }
 
-  scope :active, -> { non_archived.not_aimed_for_deletion }
+  scope :active, -> { self_and_ancestors_active }
+  scope :self_active, -> { self_non_archived.self_not_aimed_for_deletion }
   scope :self_and_ancestors_active, -> { self_and_ancestors_non_archived.self_and_ancestors_not_aimed_for_deletion }
 
-  scope :inactive, -> do
+  scope :inactive, -> { self_or_ancestors_inactive }
+  scope :self_inactive, -> do
+    namespace_setting_reflection = reflect_on_association(:namespace_settings)
+    namespace_setting_table = Arel::Table.new(namespace_setting_reflection.table_name)
+
+    deletion_schedule_reflection = reflect_on_association(:deletion_schedule)
+    deletion_schedule_table = Arel::Table.new(deletion_schedule_reflection.table_name)
+
     joins(:namespace_settings)
       .left_joins(:deletion_schedule)
-      .where(<<~SQL)
-        #{reflections['namespace_settings'].table_name}.archived = TRUE
-        OR #{reflections['deletion_schedule'].table_name}.#{reflections['deletion_schedule'].foreign_key} IS NOT NULL
-      SQL
+      .where(
+        namespace_setting_table[:archived].eq(true)
+          .or(deletion_schedule_table[:group_id].not_eq(nil))
+      )
   end
   scope :self_or_ancestors_inactive, -> { self_or_ancestors_archived.or(self_or_ancestors_aimed_for_deletion) }
 
@@ -269,7 +279,7 @@ class Group < Namespace
     where('id IN (SELECT id FROM accessible_sub_namespace_ids)')
   end
 
-  scope :by_id, ->(groups) { where(id: groups) }
+  scope :by_id, ->(groups) { id_in(groups) }
 
   scope :by_ids_or_paths, ->(ids, paths) do
     return by_id(ids) unless paths.present?
@@ -726,6 +736,12 @@ class Group < Namespace
     add_member(user, :reporter, current_user: current_user)
   end
 
+  def add_security_manager(user, current_user = nil)
+    return unless Gitlab::Security::SecurityManagerConfig.enabled?
+
+    add_member(user, :security_manager, current_user: current_user)
+  end
+
   def add_developer(user, current_user = nil)
     add_member(user, :developer, current_user: current_user)
   end
@@ -1162,6 +1178,12 @@ class Group < Namespace
     feature_flag_enabled_for_self_or_ancestor?(:allow_iframes_in_markdown, type: :wip)
   end
 
+  def work_items_saved_views_enabled?(user = nil)
+    return true if feature_flag_enabled_for_self_or_ancestor?(:work_items_saved_views, type: :wip)
+
+    user.present? && Feature.enabled?(:work_items_saved_views_user, user)
+  end
+
   def work_items_consolidated_list_enabled?(user = nil)
     # work_item_planning_view is the feature flag used to determine whether the consolidated list is enabled or not
     return true if feature_flag_enabled_for_self_or_ancestor?(:work_item_planning_view, type: :wip)
@@ -1169,10 +1191,10 @@ class Group < Namespace
     user.present? && Feature.enabled?(:work_items_consolidated_list_user, user)
   end
 
-  def supports_group_work_items?
-    ::WorkItems::TypesFilter.new(container: self).allowed_types.present?
+  def use_work_item_url?
+    work_items_consolidated_list_enabled? &&
+      !feature_flag_enabled_for_self_or_ancestor?(:work_item_legacy_url, type: :gitlab_com_derisk)
   end
-  strong_memoize_attr :supports_group_work_items?
 
   # overriden in EE
   def has_active_hooks?(hooks_scope = :push_hooks)
@@ -1292,13 +1314,18 @@ class Group < Namespace
     deletion_schedule.marked_for_deletion_on.future?
   end
 
-  def assigning_role_too_high?(current_user, access_level)
-    return false if current_user.can_admin_all_resources?
-    return false unless access_level
+  def unarchive_descendants!
+    NamespaceSetting
+      .where(namespace_id: descendant_ids, archived: true)
+      .update_all(archived: false)
+  end
 
-    max_access_level = max_member_access(current_user)
-
-    !Gitlab::Access.level_encompasses?(current_access_level: max_access_level, level_to_assign: access_level)
+  def unarchive_all_projects!
+    Project
+      .joins(:namespace)
+      .where("namespaces.traversal_ids @> '{?}'", id)
+      .where(archived: true)
+      .update_all(archived: false)
   end
 
   private
