@@ -133,7 +133,27 @@ class InstanceConfiguration
         requests_per_period: application_settings[:users_get_by_id_limit],
         period_in_seconds: 10.minutes
       },
-      pipeline_creation: application_setting_limit_per_minute(:pipeline_limit_per_project_user_sha)
+      pipeline_creation: application_setting_limit_per_minute(:pipeline_limit_per_project_user_sha),
+      users_api_followers: application_setting_limit_per_minute(:users_api_limit_followers),
+      users_api_following: application_setting_limit_per_minute(:users_api_limit_following),
+      users_api_status: application_setting_limit_per_minute(:users_api_limit_status),
+      users_api_ssh_keys: application_setting_limit_per_minute(:users_api_limit_ssh_keys),
+      users_api_ssh_key: application_setting_limit_per_minute(:users_api_limit_ssh_key),
+      users_api_gpg_keys: application_setting_limit_per_minute(:users_api_limit_gpg_keys),
+      users_api_gpg_key: application_setting_limit_per_minute(:users_api_limit_gpg_key),
+      groups_api: application_setting_limit_per_minute(:groups_api_limit),
+      group_api: application_setting_limit_per_minute(:group_api_limit),
+      group_projects_api: application_setting_limit_per_minute(:group_projects_api_limit),
+      group_shared_groups_api: application_setting_limit_per_minute(:group_shared_groups_api_limit),
+      group_invited_groups_api: application_setting_limit_per_minute(:group_invited_groups_api_limit),
+      group_archive_unarchive_api: application_setting_limit_per_minute(:group_archive_unarchive_api_limit),
+      projects_api: application_setting_limit_per_minute(:projects_api_limit),
+      projects_api_unauthenticated: application_setting_limit_per_minute(:projects_api_rate_limit_unauthenticated),
+      project_api: application_setting_limit_per_minute(:project_api_limit),
+      user_projects_api: application_setting_limit_per_minute(:user_projects_api_limit),
+      user_contributed_projects_api: application_setting_limit_per_minute(:user_contributed_projects_api_limit),
+      user_starred_projects_api: application_setting_limit_per_minute(:user_starred_projects_api_limit),
+      project_members_api: application_setting_limit_per_minute(:project_members_api_limit)
     }
   end
 
