@@ -48,10 +48,10 @@ class Issue < ApplicationRecord
   #
   # This should be kept consistent with the enums used for the GraphQL issue list query in
   # https://gitlab.com/gitlab-org/gitlab/-/blob/1379c2d7bffe2a8d809f23ac5ef9b4114f789c07/app/assets/javascripts/issues/list/constants.js#L154-158
-  TYPES_FOR_LIST = %w[issue incident test_case task objective key_result].freeze
+  TYPES_FOR_LIST = %w[issue incident test_case task objective key_result ticket].freeze
 
   # Types of issues that should be displayed on issue board lists
-  TYPES_FOR_BOARD_LIST = %w[issue incident].freeze
+  TYPES_FOR_BOARD_LIST = %w[issue incident ticket].freeze
 
   # This default came from the enum `issue_type` column. Defined as default in the DB
   DEFAULT_ISSUE_TYPE = :issue
@@ -257,12 +257,14 @@ class Issue < ApplicationRecord
 
   scope :service_desk, -> {
     where(
-      "(author_id = ? AND work_item_type_id = ?) OR work_item_type_id = ?",
-      Users::Internal.support_bot.id,
-      WorkItems::Type.default_issue_type.id,
-      WorkItems::Type.default_by_type(:ticket).id
+      author: User.support_bot,
+      work_item_type: WorkItems::Type.default_issue_type
+    )
+    .or(
+      where(work_item_type: WorkItems::Type.default_by_type(:ticket))
     )
   }
+
   scope :inc_relations_for_view, -> do
     includes(author: :status, assignees: :status)
     .allow_cross_joins_across_databases(url: 'https://gitlab.com/gitlab-org/gitlab/-/issues/422155')
@@ -727,7 +729,7 @@ class Issue < ApplicationRecord
   end
 
   def from_service_desk?
-    author_id == Users::Internal.support_bot_id
+    author.support_bot?
   end
 
   def issue_link_type
@@ -881,12 +883,11 @@ class Issue < ApplicationRecord
     epic_work_item? && group_level?
   end
 
+  # Service Desk issues and incidents should not use the work item view,
+  # since these have not been migrated over to using the work items framework.
+  # These should continue to use the .../issues/... path and render as issues.
   def show_as_work_item?
-    # Service Desk issues and incidents should not use the work item view, since these have not been migrated over to
-    # using the work items framework. These should continue to use the .../issues/... path and render as issues.
-    !from_service_desk? &&
-      !work_item_type&.incident? &&
-      Feature.enabled?(:work_item_view_for_issues, project&.group)
+    !from_service_desk? && !work_item_type&.incident?
   end
 
   def ensure_work_item_description
@@ -902,6 +903,13 @@ class Issue < ApplicationRecord
     )
   end
 
+  def ==(other)
+    return super unless id.present?
+
+    other.is_a?(Issue) && other.id == id
+  end
+  alias_method :eql?, :==
+
   private
 
   def due_date_after_start_date
