@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 
 class IssueAssignee < ApplicationRecord
+  include EachBatch
+
   extend SuppressCompositePrimaryKeyWarning
 
   belongs_to :issue
@@ -10,6 +12,7 @@ class IssueAssignee < ApplicationRecord
 
   scope :in_projects, ->(project_ids) { joins(:issue).where(issues: { project_id: project_ids }) }
   scope :on_issues, ->(issue_ids) { where(issue_id: issue_ids) }
+  scope :on_users, ->(user_ids) { where(user_id: user_ids) }
   scope :for_assignee, ->(user) { where(assignee: user) }
 end
 
