@@ -73,32 +73,26 @@ class MergeRequest < ApplicationRecord
   has_many :merge_request_context_commits, inverse_of: :merge_request
   has_many :merge_request_context_commit_diff_files, through: :merge_request_context_commits, source: :diff_files
 
-  if Gitlab.next_rails?
-    has_many :generated_ref_commits,
-      primary_key: [:iid, :target_project_id],
-      class_name: 'MergeRequests::GeneratedRefCommit',
-      foreign_key: [:merge_request_iid, :project_id],
-      inverse_of: :merge_request
-  else
-    has_many :generated_ref_commits,
-      primary_key: [:iid, :target_project_id],
-      class_name: 'MergeRequests::GeneratedRefCommit',
-      foreign_key: :merge_request_iid,
-      inverse_of: :merge_request,
-      query_constraints: [:merge_request_iid, :project_id]
-  end
+  has_many :generated_ref_commits,
+    primary_key: [:iid, :target_project_id],
+    class_name: 'MergeRequests::GeneratedRefCommit',
+    foreign_key: [:merge_request_iid, :project_id],
+    inverse_of: :merge_request
 
   has_one :merge_request_diff,
     -> { regular.order('merge_request_diffs.id DESC') }, inverse_of: :merge_request
+  # Enabling inverse relationship causes previously cached merge_head_diff to be returned as merge_request_diff
+  # MR: https://gitlab.com/gitlab-org/gitlab/-/merge_requests/214072
   has_one :merge_head_diff,
-    -> { merge_head }, inverse_of: :merge_request, class_name: 'MergeRequestDiff'
+    -> { merge_head }, inverse_of: false, class_name: 'MergeRequestDiff'
   has_one :cleanup_schedule, inverse_of: :merge_request
   has_one :predictions, inverse_of: :merge_request
   delegate :suggested_reviewers, to: :predictions
 
   has_one :merge_schedule, class_name: 'MergeRequests::MergeSchedule', inverse_of: :merge_request
   has_one :metrics, inverse_of: :merge_request, autosave: true
-  has_one :merge_data, class_name: 'MergeRequests::MergeData', inverse_of: :merge_request, foreign_key: :merge_request_id
+  # NOTE: We do not want to autosave merge_data as this is saved manually
+  has_one :merge_data, class_name: 'MergeRequests::MergeData', inverse_of: :merge_request, foreign_key: :merge_request_id, autosave: false
 
   belongs_to :latest_merge_request_diff, class_name: 'MergeRequestDiff'
   manual_inverse_association :latest_merge_request_diff, :merge_request
@@ -179,6 +173,7 @@ class MergeRequest < ApplicationRecord
   after_update :clear_memoized_shas
   after_update :reload_diff_if_branch_changed
   after_save :keep_around_commit, unless: :importing?
+  after_save :save_merge_data_changes
   after_commit :ensure_metrics!, on: [:create, :update], unless: :importing?
   after_commit :expire_etag_cache, unless: :importing?
 
@@ -301,6 +296,15 @@ class MergeRequest < ApplicationRecord
       end
     end
 
+    after_transition any => :can_be_merged do |merge_request, transition|
+      next unless Feature.enabled?(:auto_merge_on_merge_status_change, merge_request.project)
+      next unless merge_request.auto_merge_enabled?
+
+      merge_request.run_after_commit do
+        AutoMergeProcessWorker.perform_async({ 'merge_request_id' => merge_request.id })
+      end
+    end
+
     # rubocop: disable CodeReuse/ServiceClass
     after_transition [:unchecked, :checking] => :cannot_be_merged do |merge_request, transition|
       if merge_request.notify_conflict?
@@ -367,7 +371,7 @@ class MergeRequest < ApplicationRecord
     includes(:target_project)
   end
   scope :by_commit_sha, ->(project, sha) do
-    if Feature.enabled?(:commit_sha_scope_logger, type: :ops)
+    if Feature.enabled?(:commit_sha_scope_logger, type: :ops) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- pre-existing ff, ops flag
       Gitlab::AppLogger.info(
         event: 'merge_request_by_commit_sha_call',
         message: "MergeRequest.by_commit_sha called via #{caller_locations.reject { |line| line.path.include?('/gems/') }.first}"
@@ -392,7 +396,7 @@ class MergeRequest < ApplicationRecord
     joins(:generated_ref_commits).where(p_generated_ref_commits: { commit_sha: sha })
   end
   scope :by_related_commit_sha, ->(project, sha) do
-    if Feature.enabled?(:commit_sha_scope_logger, type: :ops)
+    if Feature.enabled?(:commit_sha_scope_logger, type: :ops) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- pre-existing ff, ops flag
       Gitlab::AppLogger.info(
         event: 'merge_request_by_related_commit_sha_call',
         message: "MergeRequest.by_related_commit_sha called via #{caller_locations.reject { |line| line.path.include?('/gems/') }.first}"
@@ -435,12 +439,10 @@ class MergeRequest < ApplicationRecord
   scope :references_project, -> { references(:target_project) }
   scope :with_api_entity_associations, -> {
     preload_routables.preload(
-      :assignees, :author, :unresolved_notes, :labels, :milestone,
-      :timelogs, :latest_merge_request_diff, :reviewers,
-      :merge_schedule, :merge_user,
-      target_project: [:project_feature, :project_setting, { namespace: :namespace_settings_with_ancestors_inherited_settings }],
-      metrics: [:latest_closed_by, :merged_by]
-    )
+      :assignees, :author, :unresolved_notes, :labels, :milestone, :timelogs, :reviewers, :merge_schedule, :merge_user,
+      latest_merge_request_diff: [:merge_request_diff_commits], target_project: [:project_feature, :project_setting,
+        { namespace: :namespace_settings_with_ancestors_inherited_settings }],
+      metrics: [:latest_closed_by, :merged_by])
   }
 
   scope :with_csv_entity_associations, -> { preload(:assignees, :approved_by_users, :author, :milestone, metrics: [:merged_by]) }
@@ -474,7 +476,13 @@ class MergeRequest < ApplicationRecord
   scope :preload_author, -> { preload(:author) }
   scope :preload_approved_by_users, -> { preload(:approved_by_users) }
   scope :preload_metrics, ->(relation) { preload(metrics: relation) }
-  scope :preload_project_and_latest_diff, -> { preload(:source_project, :latest_merge_request_diff) }
+  scope :preload_merge_data, ->(project) do
+    return all unless Feature.enabled?(:merge_requests_merge_data_dual_write, project)
+
+    preload(:merge_data)
+  end
+
+  scope :preload_project_and_latest_diff, -> { preload(:source_project, :target_project, :latest_merge_request_diff) }
 
   scope :preload_latest_diff_commit, ->(project) do
     if Feature.enabled?(:merge_request_diff_commits_dedup, project)
@@ -875,7 +883,7 @@ class MergeRequest < ApplicationRecord
   end
 
   def self.use_locked_set?
-    Feature.enabled?(:unstick_locked_merge_requests_redis)
+    Feature.enabled?(:unstick_locked_merge_requests_redis) # rubocop:disable Gitlab/FeatureFlagWithoutActor -- pre-existing feature flag
   end
 
   def recent_commits(limit: MergeRequestDiff::COMMITS_SAFE_SIZE, load_from_gitaly: false, page: nil, preload_metadata: false)
@@ -992,7 +1000,7 @@ class MergeRequest < ApplicationRecord
   # This helps tracking enqueued and ongoing merge jobs.
   def merge_async(user_id, params)
     jid = MergeWorker.with_status.perform_async(id, user_id, params.to_h)
-    update_column(:merge_jid, jid)
+    update_merge_jid(jid)
 
     # merge_ongoing? depends on merge_jid
     # expire etag cache since the attribute is changed without triggering callbacks
@@ -1626,7 +1634,7 @@ class MergeRequest < ApplicationRecord
   end
 
   def auto_merge_strategy=(strategy)
-    merge_params['auto_merge_strategy'] = strategy
+    append_merge_params({ 'auto_merge_strategy' => strategy })
   end
 
   def remove_source_branch?
@@ -2598,6 +2606,8 @@ class MergeRequest < ApplicationRecord
   end
 
   def diff_head_pipeline_considered_in_progress?
+    return true if pipeline_creating?
+
     pipeline = diff_head_pipeline
     return false unless pipeline
 
@@ -2714,49 +2724,83 @@ class MergeRequest < ApplicationRecord
     all_commits.exists?(sha: sha)
   end
 
-  # Override state machine methods to sync to merge_data
-  %w[preparing unchecked checking mergeable unmergeable].each do |state|
-    define_method(:"mark_as_#{state}") do
-      if should_sync_merge_data?
-        ensure_merge_data
-
-        result = super()
-
-        if result
-          begin
-            # rubocop:disable GitlabSecurity/PublicSend -- temporary manual delegation
-            merge_data_result = merge_data.send(:"mark_as_#{state}")
-            # rubocop:enable GitlabSecurity/PublicSend
-
-            unless merge_data_result
-              Gitlab::AppLogger.warn(
-                message: "Failed to set merge_status to #{state} on MergeData",
-                merge_request_id: id,
-                value_on_merge_request: merge_status,
-                value_on_merge_data: merge_data.merge_status_name.to_s
-              )
-            end
-          rescue StandardError => e
-            Gitlab::ErrorTracking.track_exception(e,
-              message: "Failed to set merge_status to #{state} on MergeData",
-              merge_request_id: id,
-              value_on_merge_request: merge_status,
-              value_on_merge_data: merge_data.merge_status_name.to_s
-            )
-          end
-        end
-
-        result
-      else
-        super()
-      end
+  %w[
+    merge_status
+    merge_params
+    merge_error
+    merge_user_id
+    merge_user
+    merge_jid
+    merge_commit_sha
+    merged_commit_sha
+    merge_ref_sha
+    squash_commit_sha
+    in_progress_merge_commit_sha
+    auto_merge_enabled
+    squash
+  ].each do |column_name|
+    define_method(:"#{column_name}=") do |value|
+      # rubocop:disable GitlabSecurity/PublicSend -- temporary manual delegation
+      with_merge_data_sync(
+        -> { super(value) },
+        -> { merge_data.public_send(__method__, value) }
+      )
+      # rubocop:enable GitlabSecurity/PublicSend
     end
   end
 
+  def append_merge_params(params)
+    with_merge_data_sync(
+      -> { merge_params.merge!(params) },
+      -> { merge_data.merge_params.merge!(params) }
+    )
+  end
+
+  def clear_merge_params(param_keys)
+    with_merge_data_sync(
+      -> { merge_params.except!(*param_keys) },
+      -> { merge_data.merge_params.except!(*param_keys) }
+    )
+  end
+
+  def update_merge_ref_sha(sha)
+    with_single_transaction_merge_data_sync(
+      -> { update_column(:merge_ref_sha, sha) },
+      -> do
+        # update_column only works if the record is already saved.
+        if merge_data.persisted?
+          merge_data.update_column(:merge_ref_sha, sha)
+        else
+          merge_data.update_attribute(:merge_ref_sha, sha)
+        end
+      end
+    )
+  end
+
+  def update_merge_jid(jid)
+    with_single_transaction_merge_data_sync(
+      -> { update_column(:merge_jid, jid) },
+      -> do
+        # update_column only works if the record is already saved.
+        if merge_data.persisted?
+          merge_data.update_column(:merge_jid, jid)
+        else
+          merge_data.update_attribute(:merge_jid, jid)
+        end
+      end
+    )
+  end
+
   def ensure_merge_data
     # Eventually we probably need to set up a callback for this, but we need to
     #   conditionally initialize this for now.
-    merge_data || build_merge_data(merge_data_attributes)
+    record = merge_data || build_merge_data(merge_data_attributes)
+
+    # id may not have been set if the merge_request got saved after the initial
+    #   ensure_merge_data so we need to set merge_request_id here if it is not already set.
+    record.merge_request_id ||= id
+    record.project_id ||= target_project_id
+    record
   end
 
   private
@@ -2764,7 +2808,7 @@ class MergeRequest < ApplicationRecord
   def merge_data_attributes
     {
       project: project,
-      merge_status: MergeRequests::MergeData::MERGE_STATUSES[merge_status.to_sym],
+      merge_status: read_attribute(:merge_status),
       merge_params: read_attribute(:merge_params),
       merge_error: read_attribute(:merge_error),
       merge_user_id: read_attribute(:merge_user_id),
@@ -2774,14 +2818,65 @@ class MergeRequest < ApplicationRecord
       merge_ref_sha: read_attribute(:merge_ref_sha),
       squash_commit_sha: read_attribute(:squash_commit_sha),
       in_progress_merge_commit_sha: read_attribute(:in_progress_merge_commit_sha),
-      auto_merge_enabled: read_attribute(:merge_when_pipeline_succeeds),
+      auto_merge_enabled: read_attribute(:auto_merge_enabled),
       squash: read_attribute(:squash)
     }
   end
 
-  def should_sync_merge_data?
+  def with_merge_data_sync(merge_request_block, merge_data_block)
+    if dual_write_to_merge_data_ff_enabled?
+      # We want to ensure the new merge_data is initialized with the current
+      # attributes before we update it.
+      ensure_merge_data
+      result = merge_request_block.call
+
+      begin
+        merge_data_block.call
+
+      rescue StandardError => e
+        Gitlab::ErrorTracking.track_exception(e,
+          message: "Failed to sync MergeData",
+          merge_request_id: id
+        )
+      end
+
+      result
+    else
+      merge_request_block.call
+    end
+  end
+
+  def with_single_transaction_merge_data_sync(merge_request_block, merge_data_block)
+    if dual_write_to_merge_data_ff_enabled?
+      result = nil
+      ensure_merge_data
+
+      ApplicationRecord.transaction do
+        result = merge_request_block.call
+        merge_data_block.call
+      end
+
+      result
+    else
+      merge_request_block.call
+    end
+  end
+
+  def save_merge_data_changes
+    return unless dual_write_to_merge_data_ff_enabled?
+    return unless merge_data&.changed?
+
+    # id is set when merge_request gets saved so we need to manually
+    #   set merge_request_id here if it is not already set.
+    merge_data.merge_request_id ||= id
+    merge_data.project_id ||= target_project_id
+    merge_data.save!
+  end
+
+  def dual_write_to_merge_data_ff_enabled?
     Feature.enabled?(:merge_requests_merge_data_dual_write, project)
   end
+  strong_memoize_attr :dual_write_to_merge_data_ff_enabled?
 
   def viewable_diffs(order_by: :id_asc)
     strong_memoize_with(:viewable_diffs, order_by) do
