@@ -12,6 +12,7 @@ class MergeRequestDiffFile < ApplicationRecord
   alias_attribute :index, :relative_order
 
   before_validation :update_project_id
+  before_validation :deduplicate_new_path
 
   scope :by_paths, ->(paths) do
     where("new_path in (?) OR old_path in (?)", paths, paths)
@@ -53,6 +54,10 @@ class MergeRequestDiffFile < ApplicationRecord
     end
   end
 
+  def new_path
+    super.presence || old_path
+  end
+
   private
 
   def update_project_id
@@ -61,6 +66,12 @@ class MergeRequestDiffFile < ApplicationRecord
     self.project_id = merge_request_diff&.project_id
   end
 
+  def deduplicate_new_path
+    return unless project_id && Feature.enabled?(:deduplicate_new_path_value, Project.find(project_id))
+
+    self.new_path = nil if new_path == old_path
+  end
+
   # This method is meant to be used during Project Export.
   # It is identical to the behavior in #diff with the only
   # difference of caching externally stored diffs on local disk in
