@@ -21,6 +21,8 @@ module MergeRequests
       cannot_be_merged_rechecking: 6
     }.freeze
 
+    enum :merge_status, MERGE_STATUSES, scope: false, instance_methods: false
+
     belongs_to :merge_request, inverse_of: :merge_data
     belongs_to :project
     belongs_to :merge_user, class_name: 'User'
@@ -28,7 +30,6 @@ module MergeRequests
     validates :project, presence: true
     validates :merge_request, presence: true
     validates :merge_status, presence: true
-    validates :merge_status, inclusion: { in: MERGE_STATUSES.values }
 
     sha_attribute :merge_commit_sha
     sha_attribute :merged_commit_sha
@@ -61,13 +62,13 @@ module MergeRequests
         transition [:unchecked, :cannot_be_merged_recheck, :checking, :cannot_be_merged_rechecking] => :cannot_be_merged
       end
 
-      state :preparing, value: MERGE_STATUSES[:preparing]
-      state :unchecked, value: MERGE_STATUSES[:unchecked]
-      state :cannot_be_merged_recheck, value: MERGE_STATUSES[:cannot_be_merged_recheck]
-      state :checking, value: MERGE_STATUSES[:checking]
-      state :cannot_be_merged_rechecking, value: MERGE_STATUSES[:cannot_be_merged_rechecking]
-      state :can_be_merged, value: MERGE_STATUSES[:can_be_merged]
-      state :cannot_be_merged, value: MERGE_STATUSES[:cannot_be_merged]
+      state :preparing
+      state :unchecked
+      state :cannot_be_merged_recheck
+      state :checking
+      state :cannot_be_merged_rechecking
+      state :can_be_merged
+      state :cannot_be_merged
 
       around_transition do |merge_data, _transition, block|
         Gitlab::Timeless.timeless(merge_data, &block)
@@ -84,7 +85,7 @@ module MergeRequests
     # Returns current merge_status except it returns `cannot_be_merged_rechecking` as `checking`
     # to avoid exposing unnecessary internal state
     def public_merge_status
-      cannot_be_merged_rechecking? || preparing? ? 'checking' : merge_status_name.to_s
+      cannot_be_merged_rechecking? || preparing? ? 'checking' : merge_status
     end
   end
 end
