@@ -11,12 +11,14 @@ class NamespaceSetting < ApplicationRecord
   columns_changing_default :require_dpop_for_manage_api_endpoints
 
   ignore_column :token_expiry_notify_inherited, remove_with: '17.9', remove_after: '2025-01-11'
-  ignore_column :enable_auto_assign_gitlab_duo_pro_seats, remove_with: '18.5', remove_after: '2025-09-12'
   enum :pipeline_variables_default_role, ProjectCiCdSetting::PIPELINE_VARIABLES_OVERRIDE_ROLES, prefix: true
 
   ignore_column :third_party_ai_features_enabled, remove_with: '16.11', remove_after: '2024-04-18'
   ignore_column :code_suggestions, remove_with: '17.8', remove_after: '2024-05-16'
   ignore_column :job_token_policies_enabled, remove_with: '18.5', remove_after: '2025-09-13'
+  ignore_column :duo_agent_platform_request_count, remove_with: '18.9', remove_after: '2026-01-16'
+  ignore_columns :early_access_program_participant, :early_access_program_joined_by_id,
+    remove_with: '18.10', remove_after: '2026-03-13'
 
   cascading_attr :math_rendering_limits_enabled, :resource_access_token_notify_inherited, :web_based_commit_signing_enabled
 
@@ -64,7 +66,6 @@ class NamespaceSetting < ApplicationRecord
       .enabled_providers(scope: Gitlab::Auth::Oidc::StepUpAuthentication::SCOPE_NAMESPACE)
       .map(&:to_s)
   } }, allow_nil: true
-  validates :duo_agent_platform_request_count, numericality: { greater_than_or_equal_to: 0 }
 
   validate :validate_step_up_auth_inheritance, if: :will_save_change_to_step_up_auth_required_oauth_provider?
 
@@ -98,7 +99,6 @@ class NamespaceSetting < ApplicationRecord
     math_rendering_limits_enabled
     lock_math_rendering_limits_enabled
     jwt_ci_cd_job_token_enabled
-    allow_personal_snippets
   ].freeze
 
   # matches the size set in the database constraint
