@@ -4,19 +4,18 @@ module Packages
   module Debian
     class FileEntry
       include ActiveModel::Model
-      include ::Packages::FIPS
 
       DIGESTS = %i[md5 sha1 sha256].freeze
-      FILENAME_REGEX = %r{\A[a-zA-Z0-9][a-zA-Z0-9_.~+-]*\z}.freeze
+      FILENAME_REGEX = %r{\A[a-zA-Z0-9][a-zA-Z0-9_.~+-]*\z}
 
       attr_accessor :filename,
-                    :size,
-                    :md5sum,
-                    :section,
-                    :priority,
-                    :sha1sum,
-                    :sha256sum,
-                    :package_file
+        :size,
+        :md5sum,
+        :section,
+        :priority,
+        :sha1sum,
+        :sha256sum,
+        :package_file
 
       validates :filename, :size, :md5sum, :section, :priority, :sha1sum, :sha256sum, :package_file, presence: true
       validates :filename, format: { with: FILENAME_REGEX }
@@ -32,14 +31,12 @@ module Packages
       private
 
       def valid_package_file_digests
-        raise DisabledError, 'Debian registry is not FIPS compliant' if Gitlab::FIPS.enabled?
-
         DIGESTS.each do |digest|
           package_file_digest = package_file["file_#{digest}"]
           sum = public_send("#{digest}sum") # rubocop:disable GitlabSecurity/PublicSend
           next if package_file_digest == sum
 
-          errors.add("#{digest}sum".to_sym, "mismatch for #{filename}: #{package_file_digest} != #{sum}")
+          errors.add(:"#{digest}sum", "mismatch for #{filename}: #{package_file_digest} != #{sum}")
         end
       end
     end
