@@ -8,10 +8,12 @@ module Packages
       include Packages::Installable
 
       INSTALLABLE_STATUSES = [:default].freeze
+      FILELISTS_FILENAME = 'filelists.xml'
+      FILELISTS_SIZE_LIMITATION = 20.megabytes
 
-      enum status: { default: 0, pending_destruction: 1, processing: 2, error: 3 }
+      enum :status, { default: 0, pending_destruction: 1, processing: 2, error: 3 }
 
-      belongs_to :project, inverse_of: :repository_files
+      belongs_to :project, inverse_of: :rpm_repository_files
 
       validates :project, presence: true
       validates :file, presence: true
@@ -20,6 +22,18 @@ module Packages
       mount_file_store_uploader Packages::Rpm::RepositoryFileUploader
 
       update_project_statistics project_statistics_name: :packages_size
+
+      def self.has_oversized_filelists?(project_id:)
+        where(
+          project_id: project_id,
+          file_name: FILELISTS_FILENAME,
+          size: [FILELISTS_SIZE_LIMITATION..]
+        ).exists?
+      end
+
+      def self.installable_statuses
+        INSTALLABLE_STATUSES
+      end
     end
   end
 end
