@@ -19,6 +19,12 @@ class ProjectTeam
     add_member(user, :reporter, current_user: current_user)
   end
 
+  def add_security_manager(user, current_user: nil)
+    return unless Gitlab::Security::SecurityManagerConfig.enabled?
+
+    add_member(user, :security_manager, current_user: current_user)
+  end
+
   def add_developer(user, current_user: nil)
     add_member(user, :developer, current_user: current_user)
   end
