@@ -9,7 +9,7 @@ module ServicePing
     attribute :payload, Gitlab::Database::Type::JsonPgSafe.new
 
     validates :payload, presence: true
-    validates :recorded_at, presence: true, uniqueness: true
+    validates :recorded_at, presence: true, uniqueness: { scope: :organization_id }
 
     scope :for_current_reporting_cycle, -> do
       where(created_at: REPORTING_CADENCE.ago.beginning_of_day..)
