@@ -21,7 +21,6 @@ class WorkItem < Issue
   has_one :parent_link, class_name: '::WorkItems::ParentLink', foreign_key: :work_item_id
   has_one :work_item_parent, through: :parent_link, class_name: 'WorkItem'
   has_one :weights_source, class_name: 'WorkItems::WeightsSource'
-  has_one :work_item_transition, class_name: 'WorkItems::Transition', inverse_of: :work_item
 
   has_many :child_links, class_name: '::WorkItems::ParentLink', foreign_key: :work_item_parent_id
   has_many :work_item_children, through: :child_links, class_name: 'WorkItem',
@@ -36,6 +35,20 @@ class WorkItem < Issue
     )
   }
 
+  scope :within_namespace_hierarchy, ->(namespace) do
+    return none if namespace.nil? || namespace.traversal_ids.blank?
+
+    if namespace.traversal_ids.length == 1
+      # For root groups
+      where("namespace_traversal_ids[1] = ?", namespace.id)
+    else
+      # For subgroups
+      ids = namespace.traversal_ids
+      next_ids = ids[0..-2] + [ids[-1] + 1]
+      where(namespace_traversal_ids: ids...next_ids)
+    end
+  end
+
   scope :within_timeframe, ->(start_date, due_date, with_namespace_cte: false) do
     date_filtered_issue_ids = ::WorkItems::DatesSource
                                 .select('issue_id')
@@ -57,6 +70,14 @@ class WorkItem < Issue
       .merge(::WorkItems::WidgetDefinition.by_enabled_widget_type(type))
   end
 
+  scope :with_group_level_and_project_issues_enabled, ->(include_group_level_items: true) do
+    # All work_items belonging to groups and projects that have the :issues feature enabled
+    scope = left_joins(:project).merge(Project.with_issues_enabled)
+    # Exclude epics (project_id: nil) if include_group_level is false
+    scope = scope.project_level unless include_group_level_items
+    scope
+  end
+
   scope :with_work_item_parent_ids, ->(parent_ids) {
     joins("INNER JOIN work_item_parent_links ON work_item_parent_links.work_item_id = issues.id")
       .where(work_item_parent_links: { work_item_parent_id: parent_ids })
@@ -269,9 +290,9 @@ class WorkItem < Issue
   end
 
   def custom_notification_target_name
-    # This is needed so we match the issue events NotificationSetting::EMAIL_EVENTS
-    return 'issue' if work_item_type.issue?
-
+    # Also use `work_item` for issues.
+    # Custom work_item notifications are mapped back to the issue category
+    # until we properly transitioned the categories to work items.
     'work_item'
   end
 
@@ -397,7 +418,7 @@ class WorkItem < Issue
   end
 
   def max_depth_reached?(child_type)
-    restriction = ::WorkItems::SystemDefined::HierarchyRestriction.find_by(
+    restriction = ::WorkItems::TypesFramework::SystemDefined::HierarchyRestriction.find_by(
       parent_type_id: work_item_type_id,
       child_type_id: child_type.id
     )
@@ -477,7 +498,7 @@ class WorkItem < Issue
     return if child_links.empty?
 
     child_type_ids = child_links.joins(:work_item).distinct.pluck('issues.work_item_type_id') # rubocop:disable Database/AvoidUsingPluckWithoutLimit -- Limited number of work item types
-    restrictions = ::WorkItems::SystemDefined::HierarchyRestriction.where(
+    restrictions = ::WorkItems::TypesFramework::SystemDefined::HierarchyRestriction.where(
       parent_type_id: work_item_type_id,
       child_type_id: child_type_ids
     )
@@ -492,7 +513,7 @@ class WorkItem < Issue
   end
 
   def validate_depth(parent_link, child_links)
-    restriction = ::WorkItems::SystemDefined::HierarchyRestriction.find_by(
+    restriction = ::WorkItems::TypesFramework::SystemDefined::HierarchyRestriction.find_by(
       parent_type_id: work_item_type_id,
       child_type_id: work_item_type_id
     )
@@ -515,7 +536,7 @@ class WorkItem < Issue
   end
 
   def hierarchy_supports_parent?
-    ::WorkItems::SystemDefined::HierarchyRestriction.find_by(child_type_id: work_item_type_id).present?
+    ::WorkItems::TypesFramework::SystemDefined::HierarchyRestriction.find_by(child_type_id: work_item_type_id).present?
   end
 end
 
