@@ -20,7 +20,6 @@ class GlobalPolicy < BasePolicy
   end
 
   condition(:project_bot, scope: :user) { @user&.project_bot? }
-  condition(:migration_bot, scope: :user) { @user&.migration_bot? }
 
   condition(:service_account, scope: :user) { @user&.service_account? }
 
@@ -48,7 +47,7 @@ class GlobalPolicy < BasePolicy
   end
 
   condition(:project_studio_available, scope: :user, score: 0) do
-    ::Users::ProjectStudio.new(@user).available?
+    true
   end
 
   rule { bot & ~bot_with_quick_actions_permitted }.policy do
@@ -90,7 +89,7 @@ class GlobalPolicy < BasePolicy
 
   rule { ~can?(:access_api) }.prevent :execute_graphql_mutation
 
-  rule { blocked | (internal & ~migration_bot & ~security_bot & ~security_policy_bot) }.policy do
+  rule { blocked | (internal & ~security_bot & ~security_policy_bot) }.policy do
     prevent :access_git
   end
 
