@@ -19,12 +19,12 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
   condition(:owner) { access_level >= GroupMember::OWNER }
   condition(:maintainer) { access_level >= GroupMember::MAINTAINER }
   condition(:reporter) { access_level >= GroupMember::REPORTER }
+  condition(:security_manager) { Gitlab::Security::SecurityManagerConfig.enabled? && access_level == GroupMember::SECURITY_MANAGER }
 
   condition(:has_parent, scope: :subject) { @subject.has_parent? }
   condition(:share_with_group_locked, scope: :subject) { @subject.share_with_group_lock? }
   condition(:parent_share_with_group_locked, scope: :subject) { @subject.parent&.share_with_group_lock? }
   condition(:can_change_parent_share_with_group_lock) { can?(:change_share_with_group_lock, @subject.parent) }
-  condition(:migration_bot, scope: :user) { @user&.migration_bot? }
   condition(:can_read_group_member) { can_read_group_member? }
 
   desc "User is a project bot"
@@ -137,7 +137,6 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     prevent :admin_achievement
     prevent :admin_build
     prevent :admin_cluster
-    prevent :admin_group_member
     prevent :admin_issue
     prevent :admin_issue_board
     prevent :admin_issue_board_list
@@ -254,6 +253,10 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     enable :read_design_activity
   end
 
+  rule { can?(:read_group) & ~anonymous }.policy do
+    enable :create_saved_view
+  end
+
   rule { public_group }.policy do
     enable :read_group
     enable :read_package
@@ -290,6 +293,10 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     enable :read_internal_note
   end
 
+  rule { security_manager }.policy do
+    enable :security_manager_access
+  end
+
   rule { admin | organization_owner }.policy do
     enable :read_group
   end
@@ -453,6 +460,7 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     enable :register_group_runners
     enable :update_group_link
     enable :update_runners_registration_token
+    enable :security_manager_access
   end
 
   rule { can?(:read_nested_project_resources) }.policy do
@@ -575,11 +583,6 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     prevent :update_runners_registration_token
   end
 
-  rule { migration_bot }.policy do
-    enable :read_resource_access_tokens
-    enable :destroy_resource_access_tokens
-  end
-
   rule { can?(:admin_group) | can?(:admin_runners) }.enable :admin_group_or_admin_runners
 
   rule { can?(:remove_group) | can?(:archive_group) }.enable :view_edit_page
