@@ -11,18 +11,18 @@ class TodoPolicy < BasePolicy
     @user && @subject.target&.readable_by?(@user)
   end
 
-  desc "Todo has confidential note"
-  condition(:has_confidential_note, scope: :subject) { @subject&.note&.confidential? }
+  desc "Todo has internal note"
+  condition(:has_internal_note, scope: :subject) { @subject&.note&.confidential? }
 
-  desc "User can read the todo's confidential note"
-  condition(:can_read_todo_confidential_note) do
+  desc "User can read the todo's internal note"
+  condition(:can_read_todo_internal_note) do
     @user && @user.can?(:read_internal_note, @subject.target)
   end
 
   rule { own_todo & can_read_target }.enable :read_todo
   rule { can?(:read_todo) }.enable :update_todo
 
-  rule { has_confidential_note & ~can_read_todo_confidential_note }.policy do
+  rule { has_internal_note & ~can_read_todo_internal_note }.policy do
     prevent :read_todo
     prevent :update_todo
   end
