@@ -16,12 +16,11 @@ class UserPresenter < Gitlab::View::Presenter::Delegated
   end
 
   def profile_enable_gitpod_path
-    profile_path(user: { gitpod_enabled: true }) if application_gitpod_enabled?
+    user_settings_profile_path(user: { gitpod_enabled: true }) if application_gitpod_enabled?
   end
 
   delegator_override :saved_replies
   def saved_replies
-    return ::Users::SavedReply.none unless Feature.enabled?(:saved_replies, current_user)
     return ::Users::SavedReply.none unless current_user.can?(:read_saved_replies, user)
 
     user.saved_replies
@@ -29,8 +28,8 @@ class UserPresenter < Gitlab::View::Presenter::Delegated
 
   private
 
-  def can?(*args)
-    user.can?(*args)
+  def can?(...)
+    user.can?(...)
   end
 
   def should_be_private?
