@@ -48,12 +48,10 @@ class BaseContainerService
 
   def handle_container_type(container)
     case container
-    when Project
-      @project = container
+    when Project, Namespaces::ProjectNamespace
+      @project = container.owner_entity
     when Group
       @group = container
-    when Namespaces::ProjectNamespace
-      @project = container.project
     end
   end
 end
