@@ -8,6 +8,12 @@ module Ci
     RETRY_IN = 10.minutes
     ACCEPTABLE_DELAY = 12.hours
 
+    attr_reader :batch_size
+
+    def initialize(batch_size: BATCH_SIZE)
+      @batch_size = batch_size
+    end
+
     def execute
       objects = load_next_batch
 
@@ -16,9 +22,9 @@ module Ci
 
     def remaining_batches_count(max_batch_count:)
       Ci::DeletedObject
-        .ready_for_destruction(max_batch_count * BATCH_SIZE)
+        .ready_for_destruction(max_batch_count * batch_size)
         .size
-        .fdiv(BATCH_SIZE)
+        .fdiv(batch_size)
         .ceil
     end
 
@@ -44,7 +50,7 @@ module Ci
     end
 
     def locked_object_ids_sql
-      Ci::DeletedObject.lock_for_destruction(BATCH_SIZE).to_sql
+      Ci::DeletedObject.lock_for_destruction(batch_size).to_sql
     end
 
     def destroy_everything(objects)
