@@ -3,6 +3,8 @@
 module ContainerRegistry
   module Protection
     class CreateRuleService < BaseProjectService
+      include ContainerRegistry::Protection::InternalEventsTracking
+
       ALLOWED_ATTRIBUTES = %i[
         repository_path_pattern
         minimum_access_level_for_push
@@ -22,6 +24,8 @@ module ContainerRegistry
           return service_response_error(message: container_registry_protection_rule.errors.full_messages)
         end
 
+        track_repository_rule_creation(container_registry_protection_rule)
+
         ServiceResponse.success(payload: { container_registry_protection_rule: container_registry_protection_rule })
       rescue StandardError => e
         service_response_error(message: e.message)
