@@ -81,6 +81,7 @@ module DesignManagement
     def create_events
       by_action = @actions.group_by(&:action).transform_values { |grp| grp.map(&:design) }
 
+      track_design_actions(by_action)
       event_create_service.save_designs(current_user, **by_action)
     end
 
@@ -130,6 +131,27 @@ module DesignManagement
       end
     end
 
+    def track_design_actions(by_action)
+      by_action&.each do |action, designs|
+        event = case action
+                when :create
+                  Gitlab::WorkItems::Instrumentation::EventActions::DESIGN_CREATE
+                when :update
+                  Gitlab::WorkItems::Instrumentation::EventActions::DESIGN_UPDATE
+                else
+                  next
+                end
+
+        designs.each do
+          ::Gitlab::WorkItems::Instrumentation::TrackingService.new(
+            work_item: issue,
+            current_user: current_user,
+            event: event
+          ).execute
+        end
+      end
+    end
+
     def track_usage_metrics(action)
       if action == :update
         ::Gitlab::UsageDataCounters::IssueActivityUniqueCounter
