@@ -3,8 +3,8 @@
 module MergeRequests
   module Mergeability
     class CheckRebaseStatusService < CheckBaseService
-      identifier :need_rebase
-      description 'Checks whether the merge request needs to be rebased'
+      set_identifier :need_rebase
+      set_description 'Checks whether the merge request needs to be rebased'
 
       def execute
         return inactive unless merge_request.project.ff_merge_must_be_possible?
