@@ -18,7 +18,6 @@ module MergeRequests
     def refresh_merge_requests!
       # n + 1: https://gitlab.com/gitlab-org/gitlab-foss/issues/60289
       Gitlab::GitalyClient.allow_n_plus_1_calls { find_new_commits }
-
       # Be sure to close outstanding MRs before reloading them to avoid generating an
       # empty diff during a manual merge
       close_upon_missing_source_branch_ref
@@ -36,27 +35,19 @@ module MergeRequests
       end
 
       abort_ff_merge_requests_with_auto_merges
+
       cache_merge_requests_closing_issues
 
       merge_requests_for_source_branch.each do |mr|
         # Leave a system note if a branch was deleted/added
-        if branch_added_or_removed?
-          comment_mr_branch_presence_changed(mr)
+        comment_mr_branch_presence_changed(mr) if branch_added_or_removed?
+
+        measure_duration_aggregated(:notify_about_push) do
+          notify_about_push(mr)
         end
 
-        notify_about_push(mr)
         mark_mr_as_draft_from_commits(mr)
 
-        # Call merge request webhook with update branches
-        if Feature.disabled?(:split_refresh_worker_web_hooks, @current_user)
-          execute_mr_web_hooks(mr)
-        end
-
-        if Feature.disabled?(:split_refresh_worker_pipeline, @current_user) && !@push.branch_removed?
-          # Run at the end of the loop to avoid any potential contention on the MR object
-          refresh_pipelines_on_merge_requests(mr)
-        end
-
         merge_request_activity_counter.track_mr_including_ci_config(user: mr.author, merge_request: mr)
       end
 
@@ -76,6 +67,14 @@ module MergeRequests
       # create an `empty` diff for `closed` MRs without a source branch, keeping
       # the latest diff state as the last _valid_ one.
       merge_requests_for_source_branch.reject(&:source_branch_exists?).each do |mr|
+        Gitlab::AppLogger.info(
+          message: 'Closing merge request due to missing source branch',
+          merge_request_id: mr.id,
+          merge_request_iid: mr.iid,
+          project_id: mr.project_id,
+          source_branch: mr.source_branch
+        )
+
         MergeRequests::CloseService
           .new(project: mr.target_project, current_user: @current_user)
           .execute(mr)
@@ -91,7 +90,8 @@ module MergeRequests
       commit_ids = @commits.map(&:id)
       merge_requests = @project.merge_requests.opened
         .preload_project_and_latest_diff
-        .preload_latest_diff_commit
+        .preload_merge_data(@project)
+        .preload_latest_diff_commit(@project)
         .where(target_branch: @push.branch_name).to_a
         .select(&:diff_head_commit)
         .select do |merge_request|
@@ -152,9 +152,11 @@ module MergeRequests
       merge_requests = @project.merge_requests.opened
         .by_source_or_target_branch(@push.branch_name)
         .preload_project_and_latest_diff
+        .preload_merge_data(@project)
 
       merge_requests_from_forks = merge_requests_for_forks
         .preload_project_and_latest_diff
+        .preload_merge_data(@project)
 
       merge_requests_array = merge_requests.to_a + merge_requests_from_forks.to_a
       filter_merge_requests(merge_requests_array).each do |merge_request|
@@ -285,13 +287,17 @@ module MergeRequests
         mr_commit_ids.include?(commit.id)
       end
 
-      SystemNoteService.add_commits(
-        merge_request, merge_request.project,
-        @current_user, new_commits,
-        existing_commits, @push.oldrev
-      )
+      measure_duration_aggregated(:system_note_add_commits) do
+        SystemNoteService.add_commits(
+          merge_request, merge_request.project,
+          @current_user, new_commits,
+          existing_commits, @push.oldrev
+        )
+      end
 
-      notification_service.push_to_merge_request(merge_request, @current_user, new_commits: new_commits, existing_commits: existing_commits)
+      measure_duration_aggregated(:notification_push_to_merge_request) do
+        notification_service.push_to_merge_request(merge_request, @current_user, new_commits: new_commits, existing_commits: existing_commits)
+      end
     end
 
     def mark_mr_as_draft_from_commits(merge_request)
@@ -352,26 +358,67 @@ module MergeRequests
     end
 
     def execute_async_workers
-      if Feature.enabled?(:split_refresh_worker_web_hooks, @current_user)
-        MergeRequests::Refresh::WebHooksWorker.perform_async(
-          @project.id,
-          @current_user.id,
-          @push.oldrev,
-          @push.newrev,
-          @push.ref
-        )
+      MergeRequests::Refresh::WebHooksWorker.perform_async(
+        @project.id,
+        @current_user.id,
+        @push.oldrev,
+        @push.newrev,
+        @push.ref
+      )
+
+      MergeRequests::Refresh::PipelineWorker.perform_async(
+        @project.id,
+        @current_user.id,
+        @push.oldrev,
+        @push.newrev,
+        @push.ref,
+        params.slice(:push_options, :gitaly_context).as_json # ensure sidekiq-compatible hash argument
+      )
+    end
+
+    def measure_duration_aggregated(operation_name)
+      return yield unless log_refresh_service_duration_enabled?
+
+      start_time = current_monotonic_time
+      result = yield
+      duration = current_monotonic_time - start_time
+
+      key = :"#{operation_name}_duration_s"
+      duration_statistics[key] ||= 0
+      duration_statistics[key] += duration
+
+      result
+    end
+
+    def duration_statistics
+      @duration_statistics ||= {}
+    end
+
+    def log_refresh_service_duration_enabled?
+      strong_memoize(:log_refresh_service_duration_enabled) do
+        Feature.enabled?(:log_refresh_service_duration, @current_user)
+      end
+    end
+
+    def log_duration_data(hash)
+      return if hash.empty?
+
+      # Round all durations at the end
+      rounded_hash = hash.transform_values do |duration|
+        duration.round(Gitlab::InstrumentationHelper::DURATION_PRECISION)
       end
 
-      if Feature.enabled?(:split_refresh_worker_pipeline, @current_user)
-        MergeRequests::Refresh::PipelineWorker.perform_async(
-          @project.id,
-          @current_user.id,
-          @push.oldrev,
-          @push.newrev,
-          @push.ref,
-          params.slice(:push_options, :gitaly_context)
-        )
-      end
+      total_duration = rounded_hash.values.sum
+      hash_with_total = rounded_hash.merge(notify_about_push_total_duration_s: total_duration)
+
+      Gitlab::AppJsonLogger.info(
+        event: 'merge_requests_refresh_service_notify_about_push',
+        **hash_with_total
+      )
+    end
+
+    def current_monotonic_time
+      Gitlab::Metrics::System.monotonic_time
     end
   end
 end
