@@ -17,13 +17,26 @@ module Projects
     end
 
     def execute_deletion
-      ServiceResponse.from_legacy_hash(
-        ::Projects::UpdateService.new(
+      result = nil
+
+      Project.transaction do
+        transition_success = resource.schedule_deletion(transition_user: current_user)
+        unless transition_success
+          result = ServiceResponse.error(message: resource.project_namespace.errors.full_messages.to_sentence)
+          raise ActiveRecord::Rollback
+        end
+
+        update_service_response = ::Projects::UpdateService.new(
           resource,
           current_user,
           update_service_params
         ).execute
-      )
+
+        result = ServiceResponse.from_legacy_hash(update_service_response)
+        raise ActiveRecord::Rollback if result.error?
+      end
+
+      result
     end
 
     def update_service_params
