@@ -3,6 +3,8 @@
 module Tags
   class CreateService < BaseService
     def execute(tag_name, target, message)
+      return error('Target is empty', 400) if target.blank?
+
       valid_tag = Gitlab::GitRefValidator.validate(tag_name)
       return error('Tag name invalid', 400) unless valid_tag
 
@@ -17,6 +19,8 @@ module Tags
         return error("Tag #{tag_name} already exists", 409)
       rescue Gitlab::Git::PreReceiveError => ex
         return error(ex.message)
+      rescue Gitlab::Git::Repository::NoRepository
+        return error("Failed to create a tag: #{tag_name}", 400)
       end
 
       if new_tag
