@@ -5,6 +5,7 @@ module WorkItems
     include WidgetableService
 
     def initialize(container:, perform_spam_check: true, current_user: nil, params: {}, widget_params: {})
+      @create_source = params.delete(:create_source)
       super(
         container: container,
         current_user: current_user,
@@ -24,6 +25,7 @@ module WorkItems
       work_item = result[:issue]
 
       if work_item.valid?
+        track_work_item_create(work_item)
         success(payload(work_item))
       else
         error(work_item.errors.full_messages, :unprocessable_entity, pass_back: payload(work_item))
@@ -49,6 +51,18 @@ module WorkItems
     def skip_system_notes?
       false
     end
+
+    def track_work_item_create(work_item)
+      candidate = "work_item_create_#{@create_source}" if @create_source.present?
+      event_name = candidate if Gitlab::WorkItems::Instrumentation::EventActions.valid_event?(candidate)
+      event_name ||= Gitlab::WorkItems::Instrumentation::EventActions::CREATE
+
+      ::Gitlab::WorkItems::Instrumentation::TrackingService.new(
+        work_item: work_item,
+        current_user: current_user,
+        event: event_name
+      ).execute
+    end
   end
 end
 
