@@ -19,12 +19,10 @@ class AdminEmailWorker # rubocop:disable Scalability/IdempotentWorker
 
   private
 
-  # rubocop: disable CodeReuse/ActiveRecord
   def send_repository_check_mail
-    repository_check_failed_count = Project.where(last_repository_check_failed: true).count
+    repository_check_failed_count = Project.last_repository_check_failed.count
     return if repository_check_failed_count == 0
 
     RepositoryCheckMailer.notify(repository_check_failed_count).deliver_now
   end
-  # rubocop: enable CodeReuse/ActiveRecord
 end
