@@ -4,7 +4,7 @@ module Ci
   class DailyBuildGroupReportResultsWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :sticky
 
     sidekiq_options retry: 3
     include PipelineBackgroundQueue
