@@ -3,7 +3,7 @@
 class ReactiveCachingWorker # rubocop:disable Scalability/IdempotentWorker
   include ReactiveCacheableWorker
 
-  urgency :low
+  urgency :high
   worker_resource_boundary :cpu
   max_concurrency_limit_percentage 0.5
 end
