@@ -5,13 +5,13 @@ module UserStatusCleanup
   class BatchWorker
     include ApplicationWorker
 
-    data_consistency :always
+    data_consistency :sticky
 
     # rubocop:disable Scalability/CronWorkerContext
     include CronjobQueue
     # rubocop:enable Scalability/CronWorkerContext
 
-    feature_category :users
+    feature_category :user_profile
 
     idempotent!
 
