@@ -85,7 +85,7 @@ module Gitlab
     require_dependency Rails.root.join('lib/gitlab/middleware/rack_multipart_tempfile_factory')
     require_dependency Rails.root.join('lib/gitlab/middleware/rack_attack_headers')
     require_dependency Rails.root.join('lib/gitlab/middleware/secure_headers')
-    require_dependency Rails.root.join('lib/gitlab/middleware/cors_static_assets')
+    require_dependency Rails.root.join('lib/gitlab/middleware/static_assets_authorization')
     require_dependency Rails.root.join('lib/gitlab/runtime')
     require_dependency Rails.root.join('lib/gitlab/patch/database_config')
     require_dependency Rails.root.join('lib/gitlab/patch/redis_cache_store')
@@ -455,7 +455,7 @@ module Gitlab
     config.middleware.insert_after ActionDispatch::ShowExceptions, ::Gitlab::Middleware::JsonValidation
 
     # Insert this early in the middleware stack to bypass ActionDispatch::HostAuthorization
-    config.middleware.unshift ::Gitlab::Middleware::CorsStaticAssets
+    config.middleware.unshift ::Gitlab::Middleware::StaticAssetsAuthorization
 
     # Allow access to GitLab API from other domains
     config.middleware.insert_before Warden::Manager, Rack::Cors do
@@ -644,8 +644,10 @@ module Gitlab
     end
 
     # DO NOT PLACE ANY INITIALIZERS AFTER THIS.
-    config.after_initialize do
-      config.active_record.yaml_column_permitted_classes = [
+    config.to_prepare do
+      # Set the permitted classes during boot *and* on reload, otherwise newly reloaded classes won't be permitted.
+      # See https://guides.rubyonrails.org/configuring.html#initialization-events re: `to_prepare`.
+      Rails.application.config.active_record.yaml_column_permitted_classes = [
         Symbol, Date, Time,
         BigDecimal, # https://gitlab.com/gitlab-org/gitlab/issues/368846
         Gitlab::Diff::Position,
@@ -686,8 +688,10 @@ module Gitlab
       # [0]: https://github.com/rails/rails/commit/94d81c3c39e3ddc441c3af3f874e53b197cf3f54
       # [1]: https://salsa.debian.org/ruby-team/rails/-/commit/5663e598b41dc4e2058db22e1ee0d678e5c483ba
       #
-      ActiveRecord.yaml_column_permitted_classes = config.active_record.yaml_column_permitted_classes
+      ActiveRecord.yaml_column_permitted_classes = Rails.application.config.active_record.yaml_column_permitted_classes
+    end
 
+    config.after_initialize do
       # on_master_start yields immediately in unclustered environments and runs
       # when the primary process is done initializing otherwise.
       Gitlab::Cluster::LifecycleEvents.on_master_start do
