@@ -90,6 +90,10 @@ namespace :import do
   end
 
   resources :source_users, param: :reassignment_token, only: [] do
+    get ':namespace_id/:reassignment_token', on: :collection, action: :show, as: :namespaced_show, constraints: { namespace_id: /\d+/ }
+    post ':namespace_id/:reassignment_token/accept', on: :collection, action: :accept, as: :namespaced_accept, constraints: { namespace_id: /\d+/ }
+    post ':namespace_id/:reassignment_token/decline', on: :collection, action: :decline, as: :namespaced_decline, constraints: { namespace_id: /\d+/ }
+
     member do
       get :show
       post :accept
