@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-constraints(::Constraints::ProjectUrlConstrainer.new) do
+constraints(Projects::ProjectUrlConstraint.new) do
   # If the route has a wildcard segment, the segment has a regex constraint,
   # the segment is potentially followed by _another_ wildcard segment, and
   # the `format` option is not set to false, we need to specify that
@@ -360,7 +360,14 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
 
         get :work_items, to: 'work_items#calendar', constraints: ->(req) { req.format == :ics }
         get :work_items, to: 'work_items#rss', constraints: ->(req) { req.format == :atom }
-        resources :work_items, only: [:show, :index], param: :iid do
+
+        resources :saved_views, only: [], path: 'work_items/saved_views' do
+          member do
+            get :subscribe
+          end
+        end
+
+        resources :work_items, only: [:show, :index, :edit], param: :iid do
           collection do
             post :import_csv
             post 'import_csv/authorize', to: 'work_items#authorize'
@@ -507,7 +514,7 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
           end
         end
 
-        resources :attestations, only: [] do
+        resources :attestations, only: [:index, :show] do
           member do
             get :download
           end
@@ -545,7 +552,7 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
         defaults: { format: 'json' },
         constraints: { template_type: %r{issue|merge_request}, format: 'json' }
 
-      resource :pages, only: [:new, :show, :update, :destroy, :regenerate_unique_domain] do # rubocop: disable Cop/PutProjectRoutesUnderScope
+      resource :pages, only: [:new, :show, :update, :destroy] do # rubocop: disable Cop/PutProjectRoutesUnderScope
         post :regenerate_unique_domain # rubocop:todo Cop/PutProjectRoutesUnderScope
         resources :domains, except: :index, controller: 'pages_domains', constraints: { id: %r{[^/]+} } do # rubocop: disable Cop/PutProjectRoutesUnderScope
           member do
@@ -691,7 +698,7 @@ end
 
 # It's under /-/jira scope but cop is only checking /-/
 # rubocop: disable Cop/PutProjectRoutesUnderScope
-scope path: '(/-/jira)', constraints: ::Constraints::JiraEncodedUrlConstrainer.new, as: :jira do
+scope path: '(/-/jira)', constraints: Integrations::JiraEncodedUrlConstraint.new, as: :jira do
   scope path: '*namespace_id/:project_id',
     namespace_id: Gitlab::Jira::Dvcs::ENCODED_ROUTE_REGEX,
     project_id: Gitlab::Jira::Dvcs::ENCODED_ROUTE_REGEX do
