@@ -61,7 +61,7 @@ scope format: false do
 
     delete :merged_branches, controller: 'branches', action: :destroy_all_merged
     resources :tags, only: [:index, :show, :new, :create, :destroy]
-    resources :protected_branches, only: [:index, :show, :create, :update, :destroy, :patch], constraints: { id: Gitlab::PathRegex.git_reference_regex }
+    resources :protected_branches, only: [:index, :show, :create, :update, :destroy], constraints: { id: Gitlab::PathRegex.git_reference_regex }
     resources :protected_tags, only: [:index, :show, :create, :update, :destroy]
   end
 
@@ -122,6 +122,7 @@ resources :commit, only: [:show], constraints: { id: Gitlab::Git::Commit::SHA_PA
     get :diffs_stats
     get :diff_file
     get :discussions
+    post :discussions, to: 'commit#create_discussions'
   end
 end
 
