@@ -110,7 +110,7 @@ class Gitlab::Seeder::Packages
 
       pkg = ::Packages::CreateTemporaryPackageService.new(
         project, project.creator, {}
-      ).execute(:nuget, name: Packages::Nuget::TEMPORARY_PACKAGE_NAME)
+      ).execute(::Packages::Nuget::Package, name: Packages::Nuget::TEMPORARY_PACKAGE_NAME)
       # when using ::Packages::CreateTemporaryPackageService, packages have a fixed name and a fixed version.
       pkg.update!(name: name, version: version)
 
