@@ -18,6 +18,8 @@ module ActiveContext
 
         def search(user:, collection:, query:)
           es_query = Processor.transform(collection: collection, node: query, user: user)
+          es_query = add_source_fields(es_query, collection)
+
           result = client.search(index: collection.collection_name, body: es_query)
 
           QueryResult.new(result: result, collection: collection, user: user).authorized_results
@@ -45,6 +47,14 @@ module ActiveContext
             debug: options[:debug]
           }.compact
         end
+
+        # In ES 9.2+, vector fields are excluded from _source by default.
+        # We explicitly include them here so that MarkRepositoryAsReadyEventWorker
+        # can verify embeddings are populated. The '*' wildcard includes all
+        # non-vector fields, and we add vector fields explicitly.
+        def add_source_fields(es_query, collection)
+          es_query.merge(_source: { includes: ['*'] + collection.current_embedding_fields })
+        end
       end
     end
   end
