@@ -3,7 +3,7 @@
 module TestEntities
   module User
     class PersonEntity < Grape::Entity
-      expose :id
+      expose :id # rubocop:disable API/EntityFieldType -- needed for testing purposes
     end
   end
 end
