@@ -9,11 +9,12 @@ module API
 
     helpers do
       def current_appearance
-        @current_appearance ||= (::Appearance.current || ::Appearance.new)
+        @current_appearance ||= ::Appearance.current || ::Appearance.new
       end
     end
 
     desc 'Get the current appearance' do
+      tags ['appearance']
       success Entities::Appearance
     end
     get "application/appearance" do
@@ -21,6 +22,7 @@ module API
     end
 
     desc 'Modify appearance' do
+      tags ['appearance']
       success Entities::Appearance
       consumes ['multipart/form-data']
     end
