@@ -11,6 +11,7 @@ module API
         JOB_TOKEN_HEADER = 'HTTP_JOB_TOKEN'
         JOB_TOKEN_PARAM = :token
         LEGACY_SYSTEM_XID = '<legacy>'
+        RUNNER_TOKEN_HEADER = 'Runner-Token'
 
         def authenticate_runner!(ensure_runner_manager: true, creation_state: nil)
           track_runner_authentication
@@ -23,10 +24,15 @@ module API
           current_runner_manager&.heartbeat(runner_details)
         end
 
+        def authenticate_runner_from_header!
+          track_runner_authentication
+          forbidden! unless current_runner_from_header
+        end
+
         def get_runner_details_from_request
           return get_runner_ip unless params['info'].present?
 
-          attributes_for_keys(%w[name version revision platform architecture executor], params['info'])
+          attributes_for_keys(%w[name version revision platform architecture executor labels], params['info'])
             .merge(get_system_id_from_request)
             .merge(get_runner_config_from_request)
             .merge(get_runner_ip)
@@ -53,6 +59,16 @@ module API
           end
         end
 
+        def current_runner_from_header
+          token = headers[RUNNER_TOKEN_HEADER]
+
+          load_balancer_stick_request(::Ci::Runner, :runner, token) if token
+
+          strong_memoize(:current_runner_from_header) do
+            ::Ci::Runner.find_by_token(token.to_s)
+          end
+        end
+
         def current_runner_manager
           strong_memoize(:current_runner_manager) do
             system_xid = params.fetch(:system_id, LEGACY_SYSTEM_XID)
@@ -61,8 +77,10 @@ module API
         end
 
         def track_runner_authentication
-          if current_runner
-            metrics.increment_runner_authentication_success_counter(runner_type: current_runner.runner_type)
+          runner = current_runner || current_runner_from_header
+
+          if runner
+            metrics.increment_runner_authentication_success_counter(runner_type: runner.runner_type)
           else
             metrics.increment_runner_authentication_failure_counter
           end
@@ -115,13 +133,14 @@ module API
         end
 
         def authenticate_job_via_dependent_job!
-          # Use primary for both main and ci database as authenticating in the scope of runners will load
+          # Use primary for both main and non-main databases as authenticating in the scope of runners will load
           # Ci::Build model and other standard authn related models like License, Project and User.
           ::Gitlab::Database::LoadBalancing::SessionMap
-            .with_sessions([::ApplicationRecord, ::Ci::ApplicationRecord]).use_primary { authenticate! }
+            .with_sessions.use_primary { authenticate! }
 
           forbidden! unless current_job
           forbidden! unless can?(current_user, :read_build, current_job)
+          forbidden! unless current_authenticated_job
         end
 
         # current_job is queried by URL :id param with no authentication
@@ -152,7 +171,7 @@ module API
           # return a generic auth error with no build details.
 
           return unless current_job
-          return unless current_job == ::Ci::AuthJobFinder.new(token: job_token).execute!(allow_canceling: true)
+          return unless current_job == ::Ci::AuthJobFinder.new(token: job_token).execute!
 
           current_job
         end
@@ -183,6 +202,14 @@ module API
           too_many_requests!('Executing database migrations. Please retry later.', retry_after: 1.minute)
         end
 
+        def job_router_enabled?(runner)
+          if runner.instance_type?
+            return Feature.enabled?(:job_router_instance_runners, runner) || Feature.enabled?(:job_router, :instance)
+          end
+
+          Feature.enabled?(:job_router, runner.owner&.root_ancestor)
+        end
+
         private
 
         def processing_on_runner?(job)
