@@ -11,6 +11,7 @@ module API
 
       resource :runners do
         desc 'Register a new runner' do
+          tags ['ci_runners']
           detail "Register a new runner for the instance"
           success Entities::Ci::RunnerRegistrationDetails
           failure [[400, 'Bad Request'], [403, 'Forbidden'], [410, 'Gone']]
@@ -75,6 +76,7 @@ module API
         desc 'Delete a registered runner' do
           summary "Delete a runner by authentication token"
           failure [[403, 'Forbidden']]
+          tags ['ci_runners']
         end
         params do
           requires :token, type: String, desc: "The runner's authentication token"
@@ -90,6 +92,7 @@ module API
         desc 'Delete a registered runner manager' do
           summary 'Internal endpoint that deletes a runner manager by authentication token and system ID.'
           http_codes [[204, 'Runner manager was deleted'], [400, 'Bad Request'], [403, 'Forbidden'], [404, 'Not Found']]
+          tags ['ci_runners']
         end
         params do
           requires :token, type: String, desc: "The runner's authentication token"
@@ -114,6 +117,7 @@ module API
           summary "Verify authentication for a registered runner"
           success Entities::Ci::RunnerRegistrationDetails
           http_codes [[200, 'Credentials are valid'], [403, 'Forbidden'], [422, 'Runner is orphaned']]
+          tags ['ci_runners']
         end
         params do
           requires :token, type: String, desc: "The runner's authentication token"
@@ -129,6 +133,7 @@ module API
         desc 'Reset runner authentication token with current token' do
           success Entities::Ci::ResetTokenResult
           failure [[403, 'Forbidden']]
+          tags ['ci_runners']
         end
         params do
           requires :token, type: String, desc: 'The current authentication token of the runner'
@@ -140,6 +145,32 @@ module API
 
           present current_runner.token_with_expiration, with: Entities::Ci::ResetTokenResult
         end
+
+        resource :router do
+          before do
+            authenticate_runner_from_header!
+            Gitlab::ApplicationContext.push(runner: current_runner_from_header)
+          end
+
+          desc 'Discover Job Router information' do
+            detail 'This endpoint can be used by the runner to retrieve information about the Job Router.'
+            success Entities::Ci::JobRouter::DiscoveryInformation
+            failure [
+              { code: 403, message: '403 Forbidden' },
+              { code: 501, message: '501 Not Implemented' }
+            ]
+            tags ['ci_runners']
+          end
+          get '/discovery', urgency: :low, feature_category: :runner_core do
+            unless Gitlab::Kas.enabled? && job_router_enabled?(current_runner_from_header)
+              render_api_error!('Job Router is not available. Please contact your administrator.', 501)
+            end
+
+            present({
+              server_url: Gitlab::Kas.external_url
+            }, with: Entities::Ci::JobRouter::DiscoveryInformation)
+          end
+        end
       end
 
       resource :jobs do
@@ -155,6 +186,7 @@ module API
             [409, 'Conflict'],
             [422, 'Runner is orphaned'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :token, type: String, desc: "Runner's authentication token"
@@ -238,11 +270,12 @@ module API
             [403, 'Forbidden'],
             [409, 'Conflict'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :token, type: String, desc: "Job's authentication token"
           requires :id, type: Integer, desc: "Job's ID"
-          optional :state, type: String, desc: "Job's status: pending, running, success, failed"
+          optional :state, type: String, desc: "Job's status: running, success, failed"
           optional :checksum, type: String, desc: "Job's trace CRC32 checksum"
           optional :failure_reason, type: String, desc: "Job's failure_reason"
           optional :output, type: Hash, desc: 'Build log state' do
@@ -258,7 +291,6 @@ module API
 
           Gitlab::Metrics.add_event(:update_build)
 
-          # Handle job state updates through the service (including two-phase commit workflow)
           service = ::Ci::UpdateBuildStateService.new(job, declared_params(include_missing: false))
 
           service.execute.then do |result|
@@ -277,6 +309,7 @@ module API
             [403, 'Forbidden'],
             [416, 'Range not satisfiable'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :id, type: Integer, desc: "Job's ID"
@@ -318,6 +351,7 @@ module API
             [405, 'Artifacts support not enabled'],
             [413, 'File too large'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :id, type: Integer, desc: "Job's ID"
@@ -359,6 +393,7 @@ module API
             [405, 'Artifacts support not enabled'],
             [413, 'File too large'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :id, type: Integer, desc: "Job's ID"
@@ -402,6 +437,7 @@ module API
             [403, 'Forbidden'],
             [404, 'Artifact not found'],
             [429, 'Too Many Requests']]
+          tags ['jobs']
         end
         params do
           requires :id, type: Integer, desc: "Job's ID"
