@@ -60,16 +60,14 @@ module API
           namespace ':id/packages/conan/v2' do
             include ::API::Concerns::Packages::Conan::SharedEndpoints
             params do
-              with(type: String) do
-                requires :package_name, regexp: PACKAGE_COMPONENT_REGEX,
-                  desc: 'Package name', documentation: { example: 'my-package' }
-                requires :package_version, regexp: PACKAGE_COMPONENT_REGEX,
-                  desc: 'Package version', documentation: { example: '1.0' }
-                requires :package_username, regexp: CONAN_REVISION_USER_CHANNEL_REGEX,
-                  desc: 'Package username', documentation: { example: 'my-group+my-project' }
-                requires :package_channel, regexp: CONAN_REVISION_USER_CHANNEL_REGEX,
-                  desc: 'Package channel', documentation: { example: 'stable' }
-              end
+              requires :package_name, type: String, regexp: PACKAGE_COMPONENT_REGEX,
+                desc: 'Package name', documentation: { example: 'my-package' }
+              requires :package_version, type: String, regexp: PACKAGE_COMPONENT_REGEX,
+                desc: 'Package version', documentation: { example: '1.0' }
+              requires :package_username, type: String, regexp: CONAN_REVISION_USER_CHANNEL_REGEX,
+                desc: 'Package username', documentation: { example: 'my-group+my-project' }
+              requires :package_channel, type: String, regexp: CONAN_REVISION_USER_CHANNEL_REGEX,
+                desc: 'Package channel', documentation: { example: 'stable' }
             end
             namespace 'conans/:package_name/:package_version/:package_username/:package_channel',
               requirements: PACKAGE_REQUIREMENTS do
@@ -95,7 +93,7 @@ module API
                 get urgency: :low do
                   not_found!('Package') unless package
 
-                  revision = package.conan_recipe_revisions.order_by_id_desc.first
+                  revision = package.conan_recipe_revisions.default.order_by_id_desc.first
 
                   not_found!('Revision') unless revision.present?
 
@@ -310,7 +308,7 @@ module API
                       get urgency: :low do
                         not_found!('Package') unless package
 
-                        revision = package_revisions.order_by_id_desc.first
+                        revision = package_revisions.default.order_by_id_desc.first
 
                         not_found!('Revision') unless revision.present?
 
