@@ -21,8 +21,13 @@ module API
             model
           end
 
+          expose :runner_inputs, as: :inputs
           expose :runner_variables, as: :variables
-          expose :steps, using: Entities::Ci::JobRequest::Step
+          expose :steps, using: Entities::Ci::JobRequest::Step, unless: ->(job) do
+            job.execution_config&.run_steps.present?
+          end
+
+          expose :runtime_hooks, as: :hooks, using: Entities::Ci::JobRequest::Hook
           expose :image, using: Entities::Ci::JobRequest::Image
           expose :services, using: Entities::Ci::JobRequest::Service
           expose :artifacts, using: Entities::Ci::JobRequest::Artifacts
@@ -32,6 +37,10 @@ module API
           expose :dependencies do |job, options|
             Entities::Ci::JobRequest::Dependency.represent(job.all_dependencies, options.merge(running_job: job))
           end
+
+          expose :run, if: ->(job) { job.execution_config&.run_steps.present? } do |job|
+            job.execution_config.run_steps.to_json
+          end
         end
       end
     end
