@@ -5,16 +5,16 @@ module API
     class Environment < Entities::EnvironmentBasic
       include RequestAwareEntity
 
-      expose :tier, documentation: { type: 'string', example: 'development' }
+      expose :tier, documentation: { type: 'String', example: 'development' }
       expose :project, using: Entities::BasicProjectDetails
       expose :last_deployment, using: Entities::Deployment, if: { last_deployment: true }
-      expose :state, documentation: { type: 'string', example: 'available' }
-      expose :auto_stop_at, documentation: { type: 'dateTime', example: '2019-05-25T18:55:13.252Z' }
+      expose :state, documentation: { type: 'String', example: 'available' }
+      expose :auto_stop_at, documentation: { type: 'DateTime', example: '2019-05-25T18:55:13.252Z' }
       expose :cluster_agent, using: Entities::Clusters::Agent, if: ->(_, _) { can_read_cluster_agent? }
       expose :kubernetes_namespace, if: ->(_, _) { can_read_cluster_agent? }
       expose :flux_resource_path, if: ->(_, _) { can_read_cluster_agent? }
-      expose :description, documentation: { type: 'string', example: 'description' }
-      expose :auto_stop_setting, documentation: { type: 'string', example: 'always' }
+      expose :description, documentation: { type: 'String', example: 'description' }
+      expose :auto_stop_setting, documentation: { type: 'String', example: 'always' }
 
       private
 
