@@ -10,16 +10,16 @@ module API
       expose :project_creation_level_str, as: :project_creation_level
       expose :auto_devops_enabled
       expose :subgroup_creation_level_str, as: :subgroup_creation_level
-      expose(:emails_disabled, documentation: { type: 'boolean' }) { |group, options| group.emails_disabled? }
-      expose :emails_enabled, documentation: { type: 'boolean' }
-      expose(:show_diff_preview_in_email, documentation: { type: 'boolean' }) do |group, options|
+      expose(:emails_disabled, documentation: { type: 'Boolean' }) { |group, options| group.emails_disabled? }
+      expose :emails_enabled, documentation: { type: 'Boolean' }
+      expose(:show_diff_preview_in_email, documentation: { type: 'Boolean' }) do |group, options|
         group.show_diff_preview_in_email?
       end
       expose :mentions_disabled
       expose :lfs_enabled?, as: :lfs_enabled
-      expose(:archived, documentation: { type: 'boolean' }) { |group, _options| group.self_or_ancestors_archived? }
-      expose :math_rendering_limits_enabled, documentation: { type: 'boolean' }
-      expose :lock_math_rendering_limits_enabled, documentation: { type: 'boolean' }
+      expose(:archived, documentation: { type: 'Boolean' }) { |group, _options| group.self_or_ancestors_archived? }
+      expose :math_rendering_limits_enabled, documentation: { type: 'Boolean' }
+      expose :lock_math_rendering_limits_enabled, documentation: { type: 'Boolean' }
       expose :default_branch_name, as: :default_branch
       expose :default_branch_protection
       expose :default_branch_protection_settings, as: :default_branch_protection_defaults
@@ -32,9 +32,9 @@ module API
       expose :parent_id
       expose :organization_id
       expose :shared_runners_setting
-      expose :max_artifacts_size, documentation: { type: 'integer' }
+      expose :max_artifacts_size, documentation: { type: 'Integer' }
 
-      expose :custom_attributes, using: 'API::Entities::CustomAttribute', if: :with_custom_attributes
+      expose :custom_attributes, using: ::API::Entities::CustomAttribute, if: :with_custom_attributes
 
       expose :statistics, if: :statistics do
         with_options format_with: ->(value) { value.to_i } do
