@@ -56,7 +56,7 @@ module API
 
       expose :moved_to_id
       expose :imported?, as: :imported
-      expose :imported_from, documentation: { type: 'string', example: 'github' }
+      expose :imported_from, documentation: { type: 'String', example: 'github' }
       expose :service_desk_reply_to do |issue|
         issue.present(
           current_user: options[:current_user],
