@@ -5,7 +5,9 @@ module API
     class WikiPage < WikiPageBasic
       include ::MarkupHelper
 
-      expose :content do |wiki_page, options|
+      expose :content, documentation: {
+        type: 'String', example: 'Here is an instruction how to deploy this project.'
+      } do |wiki_page, options|
         if options[:render_html]
           render_wiki_content(
             wiki_page,
@@ -13,13 +15,17 @@ module API
             current_user: options[:current_user]
           )
         else
-          wiki_page.content
+          wiki_page.raw_content
         end
       end
 
-      expose :encoding do |wiki_page|
+      expose :encoding, documentation: { type: 'String', example: 'UTF-8' } do |wiki_page|
         wiki_page.content.encoding.name
       end
+
+      expose :front_matter, documentation: { type: 'Hash', example: { title: "deploy" } }
     end
   end
 end
+
+API::Entities::WikiPage.prepend_mod
