@@ -114,7 +114,7 @@ module API
       ::Current.organization = Gitlab::Current::Organization.new(
         params: {},
         user: user,
-        headers: request.headers
+        rack_env: request.env
       ).organization
     end
 
@@ -866,7 +866,8 @@ module API
 
     def validate_search_rate_limit!
       if current_user
-        check_rate_limit!(:search_rate_limit, scope: [current_user])
+        check_rate_limit!(:search_rate_limit, scope: [current_user],
+          users_allowlist: Gitlab::CurrentSettings.current_application_settings.search_rate_limit_allowlist)
       else
         check_rate_limit!(:search_rate_limit_unauthenticated, scope: [ip_address])
       end
@@ -1119,9 +1120,10 @@ module API
     def boundary_for_endpoint
       return unless access_token.try(:granular?)
 
-      case authorization_settings[:boundary_type]
-      when :standalone
-        ::Authz::Boundary.for(nil)
+      access = authorization_settings[:boundary_type]
+      case access
+      when :user, :instance
+        ::Authz::Boundary.for(access)
       when :group
         group = find_group(params[:group_id] || params[:id])
         ::Authz::Boundary.for(group) if group
