@@ -51,6 +51,19 @@ module API
         bad_request!('`updated_at` filter and `updated_at` sorting must be paired')
       end
 
+      def track_high_page_offset
+        return if params[:page] * params[:per_page] <= Plan.default.actual_limits.offset_pagination_limit
+
+        track_event(
+          'request_projects_api_high_offset',
+          user: current_user,
+          additional_properties: {
+            label: params[:per_page].to_s,
+            value: params[:page]
+          }
+        )
+      end
+
       def provided_order_is_not_updated_at?
         order_by_param = declared_params[:order_by]
 
@@ -214,7 +227,7 @@ module API
         projects = reorder_projects(projects) unless order_by_similarity?(allow_unauthorized: false)
         projects = apply_filters(projects)
 
-        records, options = paginate_with_strategies(projects, options[:request_scope]) do |projects|
+        records, options = paginate_with_strategies(projects, options[:request_scope], use_cursor: false) do |projects|
           projects, options = with_custom_attributes(projects, options)
 
           options = options.reverse_merge(
@@ -269,6 +282,7 @@ module API
         use :statistics_params
         use :with_custom_attributes
       end
+      route_setting :authorization, permissions: :read_project, boundary_type: :user
       get ":user_id/projects", feature_category: :groups_and_projects, urgency: :low do
         check_rate_limit_by_user_or_ip!(:user_projects_api)
 
@@ -294,6 +308,8 @@ module API
         optional :simple, type: Boolean, default: false,
           desc: 'Return only the ID, URL, name, and path of each project'
       end
+
+      route_setting :authorization, permissions: :read_contributed_project, boundary_type: :user
       get ":user_id/contributed_projects", feature_category: :groups_and_projects, urgency: :low do
         check_rate_limit_by_user_or_ip!(:user_contributed_projects_api)
 
@@ -315,6 +331,8 @@ module API
         use :collection_params
         use :statistics_params
       end
+
+      route_setting :authorization, permissions: :read_starred_project, boundary_type: :user
       get ":user_id/starred_projects", feature_category: :groups_and_projects, urgency: :low do
         check_rate_limit_by_user_or_ip!(:user_starred_projects_api)
 
@@ -331,7 +349,9 @@ module API
 
       desc 'Restore a project' do
         success ::API::Entities::Project
+        tags ['projects']
       end
+      route_setting :authorization, permissions: :restore_project, boundary_type: :project
       post ':id/restore', feature_category: :system_access do
         authorize!(:remove_project, user_project)
 
@@ -357,9 +377,11 @@ module API
         use :with_custom_attributes
       end
       # TODO: Set higher urgency https://gitlab.com/gitlab-org/gitlab/-/issues/211495
+      route_setting :authorization, permissions: :read_project, boundary_type: :user
       get feature_category: :groups_and_projects, urgency: :low do
         validate_projects_api_rate_limit!
         validate_updated_at_order_and_filter!
+        track_high_page_offset
         present_projects load_projects
       end
 
@@ -380,6 +402,7 @@ module API
         use :optional_create_project_params
         use :create_params
       end
+      route_setting :authorization, permissions: :create_project, boundary_type: :user
       post urgency: :low do
         Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/issues/21139')
         attrs = declared_params(include_missing: false)
@@ -425,6 +448,7 @@ module API
         use :create_params
       end
       # rubocop: disable CodeReuse/ActiveRecord
+      route_setting :authorization, permissions: :create_project, boundary_type: :user
       post "user/:user_id", feature_category: :groups_and_projects do
         Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/issues/21139')
         authenticated_as_admin!
@@ -452,11 +476,13 @@ module API
 
       desc 'Returns group that can be shared with the given project' do
         success Entities::Group
+        tags %w[projects groups]
       end
       params do
         requires :id, type: Integer, desc: 'The id of the project'
         optional :search, type: String, desc: 'Return list of groups matching the search criteria'
       end
+      route_setting :authorization, permissions: :read_share_location_project, boundary_type: :project
       get ':id/share_locations' do
         groups = ::Groups::AcceptingProjectSharesFinder.new(current_user, user_project, declared_params(include_missing: false)).execute
 
@@ -482,6 +508,7 @@ module API
           desc: 'Include project license data'
       end
       # TODO: Set higher urgency https://gitlab.com/gitlab-org/gitlab/-/issues/357622
+      route_setting :authorization, permissions: :read_project, boundary_type: :project
       get ":id", feature_category: :groups_and_projects, urgency: :low do
         check_rate_limit_by_user_or_ip!(:project_api)
 
@@ -518,6 +545,7 @@ module API
         optional :mr_default_target_self, type: Boolean, desc: 'Merge requests of this forked project targets itself by default'
         optional :branches, type: String, desc: 'Branches to fork'
       end
+      route_setting :authorization, permissions: :create_fork_project, boundary_type: :project
       post ':id/fork', feature_category: :source_code_management do
         Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/20759')
 
@@ -561,6 +589,7 @@ module API
         use :collection_params
         use :with_custom_attributes
       end
+      route_setting :authorization, permissions: :read_fork_project, boundary_type: :project
       get ':id/forks', feature_category: :source_code_management, urgency: :low do
         forks = ForkProjectsFinder.new(user_project, params: project_finder_params, current_user: current_user).execute
 
@@ -574,6 +603,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :read_page_access_project, boundary_type: :project
       get ':id/pages_access', urgency: :low, feature_category: :pages do
         authorize! :read_pages_content, user_project unless user_project.public_pages?
         status 200
@@ -597,6 +627,7 @@ module API
 
         at_least_one_of(*Helpers::ProjectsHelpers.update_params_at_least_one_of)
       end
+      route_setting :authorization, permissions: :update_project, boundary_type: :project
       put ':id', feature_category: :groups_and_projects do
         authorize_admin_project
         attrs = declared_params(include_missing: false)
@@ -631,6 +662,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :archive_project, boundary_type: :project
       post ':id/archive', feature_category: :groups_and_projects do
         authorize!(:archive_project, user_project)
 
@@ -650,6 +682,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :archive_project, boundary_type: :project
       post ':id/unarchive', feature_category: :groups_and_projects, urgency: :default do
         authorize!(:archive_project, user_project)
 
@@ -670,6 +703,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :star_project, boundary_type: :project
       post ':id/star', feature_category: :groups_and_projects do
         if current_user.starred?(user_project)
           not_modified!
@@ -689,6 +723,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :star_project, boundary_type: :project
       post ':id/unstar', feature_category: :groups_and_projects do
         if current_user.starred?(user_project)
           current_user.toggle_star(user_project)
@@ -713,6 +748,7 @@ module API
         optional :search, type: String, desc: 'Return list of users matching the search criteria', documentation: { example: 'user' }
         use :pagination
       end
+      route_setting :authorization, permissions: :read_starrer_project, boundary_type: :project
       get ':id/starrers', feature_category: :groups_and_projects do
         starrers = UsersStarProjectsFinder.new(user_project, params, current_user: current_user).execute
 
@@ -727,6 +763,7 @@ module API
         is_array true
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :read_language_project, boundary_type: :project
       get ':id/languages', feature_category: :source_code_management, urgency: :medium do
         ::Projects::RepositoryLanguagesService
           .new(user_project, current_user)
@@ -741,6 +778,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :delete_project, boundary_type: :project
       delete ":id", feature_category: :groups_and_projects do
         authorize! :remove_project, user_project
 
@@ -759,6 +797,7 @@ module API
       params do
         requires :forked_from_id, type: String, desc: 'The ID of the project it was forked from', documentation: { example: 'gitlab' }
       end
+      route_setting :authorization, permissions: :mark_forked_project, boundary_type: :project
       post ":id/fork/:forked_from_id", feature_category: :source_code_management do
         authorize! :link_forked_project, user_project
 
@@ -792,6 +831,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :delete_fork_project, boundary_type: :project
       delete ":id/fork", feature_category: :source_code_management do
         authorize! :remove_fork_project, user_project
 
@@ -817,6 +857,7 @@ module API
         optional :expires_at, type: Date, desc: 'Share expiration date'
         use :share_project_params_ee
       end
+      route_setting :authorization, permissions: :share_project, boundary_type: :project
       post ":id/share", feature_category: :groups_and_projects, urgency: :low do
         authorize! :admin_project, user_project
         shared_with_group = Group.find_by_id(params[:group_id])
@@ -847,6 +888,7 @@ module API
         requires :group_id, type: Integer, desc: 'The ID of the group'
       end
       # rubocop: disable CodeReuse/ActiveRecord
+      route_setting :authorization, permissions: :delete_group_share_project, boundary_type: :project
       delete ":id/share/:group_id", feature_category: :groups_and_projects do
         authorize! :admin_project, user_project
 
@@ -877,6 +919,7 @@ module API
       params do
         requires :project_id, type: Integer, desc: 'The ID of the source project to import the members from.'
       end
+      route_setting :authorization, permissions: :import_member_project, boundary_type: :project
       post ":id/import_project_members/:project_id", feature_category: :groups_and_projects do
         ::Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/355916')
         authorize! :admin_project, user_project
@@ -910,6 +953,7 @@ module API
         optional :skip_users, type: Array[Integer], coerce_with: ::API::Validations::Types::CommaSeparatedToIntegerArray.coerce, desc: 'Filter out users with the specified IDs'
         use :pagination
       end
+      route_setting :authorization, permissions: :read_user_project, boundary_type: :project
       get ':id/users', urgency: :low, feature_category: :system_access do
         users = DeclarativePolicy.subject_scope { user_project.team.users }
         users = users.search(params[:search]) if params[:search].present?
@@ -939,6 +983,7 @@ module API
           desc: 'Limit returned shared groups by minimum access level to the project'
         use :pagination
       end
+      route_setting :authorization, permissions: :read_group_project, boundary_type: :project
       get ':id/groups', feature_category: :source_code_management do
         groups = ::Projects::GroupsFinder.new(project: user_project, current_user: current_user, params: declared_params(include_missing: false)).execute
         groups = groups.search(params[:search]) if params[:search].present?
@@ -959,6 +1004,7 @@ module API
         use :pagination
         use :with_custom_attributes
       end
+      route_setting :authorization, permissions: :read_invited_group_project, boundary_type: :project
       get ':id/invited_groups', feature_category: :groups_and_projects do
         check_rate_limit_by_user_or_ip!(:project_invited_groups_api)
 
@@ -980,6 +1026,7 @@ module API
       params do
         optional :task, type: Symbol, default: :eager, values: %i[eager prune], desc: '`prune` to trigger manual prune of unreachable objects or `eager` to trigger eager housekeeping.'
       end
+      route_setting :authorization, permissions: :housekeep_project, boundary_type: :project
       post ':id/housekeeping', feature_category: :source_code_management do
         authorize_admin_project
 
@@ -1008,6 +1055,7 @@ module API
         ]
         tags %w[projects]
       end
+      route_setting :authorization, permissions: :recalculate_storage_project, boundary_type: :project
       post ':id/repository_size', feature_category: :source_code_management do
         authorize_admin_project
 
@@ -1028,6 +1076,7 @@ module API
       params do
         requires :namespace, type: String, desc: 'The ID or path of the new namespace', documentation: { example: 'gitlab' }
       end
+      route_setting :authorization, permissions: :transfer_project, boundary_type: :project
       put ":id/transfer", feature_category: :groups_and_projects do
         authorize! :change_namespace, user_project
         Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/546376')
@@ -1054,6 +1103,7 @@ module API
         optional :search, type: String, desc: 'Return list of namespaces matching the search criteria', documentation: { example: 'search' }
         use :pagination
       end
+      route_setting :authorization, permissions: :read_transfer_location_project, boundary_type: :project
       get ":id/transfer_locations", feature_category: :groups_and_projects do
         authorize! :change_namespace, user_project
         args = declared_params(include_missing: false)
@@ -1077,6 +1127,7 @@ module API
       params do
         requires :id, type: String, desc: 'ID of a project'
       end
+      route_setting :authorization, permissions: :read_storage_project, boundary_type: :project
       get ':id/storage', feature_category: :source_code_management do
         authenticated_as_admin!
 
