@@ -289,18 +289,18 @@ module API
 
         params do
           requires :content, type: ::API::Validations::Types::WorkhorseFile, desc: 'The package file to be published (generated by Multipart middleware)', documentation: { type: 'file' }
-          requires :name, type: String, documentation: { example: 'my.pypi.package' }
-          requires :version, type: String, documentation: { example: '1.3.7' }
-          optional :requires_python, type: String, documentation: { example: '>=3.7' }
-          optional :md5_digest, type: String, documentation: { example: '900150983cd24fb0d6963f7d28e17f72' }
-          optional :sha256_digest, type: String, regexp: Gitlab::Regex.sha256_regex, documentation: { example: 'ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad' }
-          optional :metadata_version, type: String, documentation: { example: '2.3' }
-          optional :author_email, type: String, documentation: { example: 'cschultz@example.com, snoopy@peanuts.com' }
-          optional :description, type: String
-          optional :description_content_type, type: String,
+          requires :name, type: String, desc: 'Name of the package', documentation: { example: 'my.pypi.package' }
+          requires :version, type: String, desc: 'Version of the package', documentation: { example: '1.3.7' }
+          optional :requires_python, type: String, desc: 'PyPI version required for the package', documentation: { example: '>=3.7' }
+          optional :md5_digest, type: String, desc: 'MD5 checksum of the package', documentation: { example: '900150983cd24fb0d6963f7d28e17f72' }
+          optional :sha256_digest, type: String, desc: 'SHA256 checksum of the package', regexp: Gitlab::Regex.sha256_regex, documentation: { example: 'ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad' }
+          optional :metadata_version, type: String, desc: 'Metadata version of the package', documentation: { example: '2.3' }
+          optional :author_email, type: String, desc: 'Email address for the package author', documentation: { example: 'cschultz@example.com, snoopy@peanuts.com' }
+          optional :description, type: String, desc: 'Description of the package'
+          optional :description_content_type, type: String, desc: 'Type of content for the package description',
             documentation: { example: 'text/markdown; charset=UTF-8; variant=GFM' }
-          optional :summary, type: String, documentation: { example: 'A module for collecting votes from beagles.' }
-          optional :keywords, type: String, documentation: { example: 'dog,puppy,voting,election' }
+          optional :summary, type: String, desc: 'Short summary of the package', documentation: { example: 'A module for collecting votes from beagles.' }
+          optional :keywords, type: String, desc: 'Keywords listed for the package', documentation: { example: 'dog,puppy,voting,election' }
         end
 
         route_setting :authentication, deploy_token_allowed: true, basic_auth_personal_access_token: true, job_token_allowed: :basic_auth
