@@ -9,6 +9,7 @@ module Banzai
       # Styles used by Markdown for table alignment
       TABLE_ALIGNMENT_PATTERN = /text-align: (?<alignment>center|left|right)/
       ALLOWED_IDIFF_CLASSES = %w[idiff left right deletion addition].freeze
+      HEADER_NODE_NAMES = %w[h1 h2 h3 h4 h5 h6].freeze
 
       def customize_allowlist(allowlist)
         allowlist[:allow_comments] = context[:allow_comments]
@@ -19,6 +20,7 @@ module Banzai
         allow_id_attributes(allowlist)
         allow_class_attributes(allowlist)
         allow_section_footnotes(allowlist)
+        allow_anchor_data_heading_content(allowlist)
         allow_tasklists(allowlist)
 
         allowlist
@@ -33,7 +35,7 @@ module Banzai
         allowlist[:css] = { properties: ['text-align'] }
 
         # Remove any `style` properties not required for table alignment
-        allowlist[:transformers].push(self.class.remove_unsafe_table_style)
+        allowlist[:transformers].push(self.class.method(:remove_unsafe_table_style))
       end
 
       def allow_json_table_attributes(allowlist)
@@ -48,11 +50,13 @@ module Banzai
       end
 
       def allow_id_attributes(allowlist)
-        # Allow `id` in `a` and `li` elements for footnotes and `a` elements for header anchors.
+        # Allow `id` in `a` and `li` elements for footnotes and `h1`~`h6` elements for header anchors.
         # Remove any `id` properties not matching these patterns via transformer
         allowlist[:attributes]['a'].push('id')
-        allowlist[:attributes]['li'] = %w[id]
-        allowlist[:transformers].push(self.class.remove_id_attributes)
+        (["li"] + HEADER_NODE_NAMES).each do |tag|
+          allowlist[:attributes][tag] = %w[id]
+        end
+        allowlist[:transformers].push(self.class.method(:remove_id_attributes))
       end
 
       def allow_class_attributes(allowlist)
@@ -76,6 +80,10 @@ module Banzai
         allowlist[:attributes]['a'].push('data-footnote-ref', 'data-footnote-backref', 'data-footnote-backref-idx')
       end
 
+      def allow_anchor_data_heading_content(allowlist)
+        allowlist[:attributes]['a'].push('data-heading-content')
+      end
+
       def allow_tasklists(allowlist)
         allowlist[:elements].push('input')
         allowlist[:attributes]['input'].push('data-inapplicable')
@@ -83,18 +91,16 @@ module Banzai
       end
 
       class << self
-        def remove_unsafe_table_style
-          ->(env) do
-            node = env[:node]
+        def remove_unsafe_table_style(env)
+          node = env[:node]
 
-            return unless node.name == 'th' || node.name == 'td'
-            return unless node.has_attribute?('style')
+          return unless node.name == 'th' || node.name == 'td'
+          return unless node.has_attribute?('style')
 
-            if node['style'] =~ TABLE_ALIGNMENT_PATTERN
-              node['style'] = "text-align: #{$~[:alignment]}"
-            else
-              node.remove_attribute('style')
-            end
+          if node['style'] =~ TABLE_ALIGNMENT_PATTERN
+            node['style'] = "text-align: #{$~[:alignment]}"
+          else
+            node.remove_attribute('style')
           end
         end
 
@@ -149,26 +155,6 @@ module Banzai
           node['class'] != 'idiff'
         end
 
-        def remove_id_attributes
-          ->(env) do
-            node = env[:node]
-
-            return unless node.name == 'a' || node.name == 'li'
-            return unless node.has_attribute?('id')
-
-            # footnote ids should not be removed
-            return if node.name == 'li' && node['id'].start_with?(Banzai::Filter::FootnoteFilter::FOOTNOTE_ID_PREFIX)
-            return if node.name == 'a' &&
-              node['id'].start_with?(Banzai::Filter::FootnoteFilter::FOOTNOTE_LINK_ID_PREFIX)
-
-            # links with generated header anchors should not be removed
-            return if node.name == 'a' && node['class'] == 'anchor' &&
-              node['id'].start_with?(Banzai::Renderer::USER_CONTENT_ID_PREFIX)
-
-            node.remove_attribute('id')
-          end
-        end
-
         def remove_ul_ol_class?(node)
           node['class'] != 'task-list'
         end
@@ -182,6 +168,29 @@ module Banzai
           node['class'] != 'task-list-item-checkbox'
         end
 
+        def remove_id_attributes(env)
+          node = env[:node]
+          return unless node.has_attribute?('id')
+
+          id = node['id']
+
+          case node.name
+          when 'a'
+            # footnote ids should not be removed
+            return if id.start_with?(Banzai::Filter::FootnoteFilter::FOOTNOTE_LINK_ID_PREFIX)
+          when 'li'
+            # footnote ids should not be removed
+            return if id.start_with?(Banzai::Filter::FootnoteFilter::FOOTNOTE_ID_PREFIX)
+          when *HEADER_NODE_NAMES
+            # headers with generated header anchors should not be removed
+            return if id.start_with?(Banzai::Renderer::USER_CONTENT_ID_PREFIX)
+          else
+            return
+          end
+
+          node.remove_attribute('id')
+        end
+
         def remove_non_tasklist_inputs(env)
           node = env[:node]
 
