@@ -13,7 +13,7 @@ module Gitlab
           :chat_data, :mirror_update, :bridge, :content, :dry_run, :linting, :logger, :pipeline_policy_context,
           # These attributes are set by Chains during processing:
           :config_content, :yaml_processor_result, :workflow_rules_result, :pipeline_seed,
-          :pipeline_config, :partition_id, :inputs, :gitaly_context,
+          :pipeline_config, :partition_id, :inputs, :gitaly_context, :pipeline_creation_forced_to_continue,
           keyword_init: true
         ) do
           include Gitlab::Utils::StrongMemoize
@@ -46,6 +46,10 @@ module Gitlab
             check_merge_request_ref
           end
 
+          def workload_ref_exists?
+            ::Ci::Workloads::Workload.workload_ref?(origin_ref) && project.repository.ref_exists?(origin_ref)
+          end
+
           def ref
             strong_memoize(:ref) do
               Gitlab::Git.ref_name(origin_ref)
@@ -98,6 +102,20 @@ module Gitlab
             self[:logger] ||= ::Gitlab::Ci::Pipeline::Logger.new(project: project)
           end
 
+          def current_pipeline_size
+            # The `pipeline_seed` attribute is assigned after the Seed step.
+            # And, the seed is populated when calling the `pipeline_seed.stages` method in Populate.
+            # So, there is no guarantee that `pipeline_seed` will return a meaningful result.
+            # If it does not, it's not important, we can just return 0.
+            # This is also the reason why we don't "strong memoize" this method.
+            pipeline_seed&.size || 0
+          end
+
+          def jobs_count_in_alive_pipelines
+            project.all_pipelines.jobs_count_in_alive_pipelines
+          end
+          strong_memoize_attr :jobs_count_in_alive_pipelines
+
           def observe_step_duration(step_class, duration)
             step = step_class.name.underscore.parameterize(separator: '_')
             logger.observe("pipeline_step_#{step}_duration_s", duration, once: true)
@@ -123,10 +141,8 @@ module Gitlab
           end
 
           def observe_jobs_count_in_alive_pipelines
-            jobs_count = project.all_pipelines.jobs_count_in_alive_pipelines
-
             metrics.active_jobs_histogram
-              .observe({ plan: project.actual_plan_name }, jobs_count)
+              .observe({ plan: project.actual_plan_name }, jobs_count_in_alive_pipelines + current_pipeline_size)
           end
 
           def increment_pipeline_failure_reason_counter(reason)
