@@ -21,6 +21,9 @@ module Gitlab
             track_keyword_usage_for('run', command.yaml_processor_result.uses_keyword?(:run))
             track_keyword_usage_for('only', command.yaml_processor_result.uses_keyword?(:only))
             track_keyword_usage_for('except', command.yaml_processor_result.uses_keyword?(:except))
+            track_keyword_usage_for('artifacts_reports_junit',
+              command.yaml_processor_result.uses_nested_keyword?(%i[artifacts reports junit]))
+            track_keyword_usage_for('job_inputs', command.yaml_processor_result.uses_keyword?(:inputs))
           end
 
           def track_keyword_usage_for(keyword, used)
