@@ -41,17 +41,14 @@ module Gitlab
 
           validates :pause_ms, numericality: { greater_than_or_equal_to: MINIMUM_PAUSE_MS }
 
-          validates :job_arguments, uniqueness: {
-            scope: [:job_class_name, :table_name, :column_name]
-          }
-
           scope :for_partition, ->(partition) { where(partition: partition) }
           scope :unfinished, -> { with_statuses(:queued, :active, :paused) }
           scope :with_job_arguments, ->(args) { where("job_arguments = ?", args.to_json) } # rubocop:disable Rails/WhereEquals -- to override Rails comparison
           scope :not_on_hold, -> { where('on_hold_until IS NULL OR on_hold_until < NOW()') }
+          scope :for_gitlab_schema, ->(gitlab_schema) { where(gitlab_schema: gitlab_schema) }
 
           scope :executable, -> do
-            with_statuses(:queued, :paused).not_on_hold
+            with_statuses(:queued, :active, :paused).not_on_hold
           end
 
           scope :unfinished_with_config, ->(job_class_name, table_name, column_name, job_arguments, org_id: nil) do
@@ -93,17 +90,21 @@ module Gitlab
             state :failed, value: 4
 
             event :finish do
-              transition [:paused, :finished, :active, :finalizing] => :finished
+              transition [:queued, :paused, :finished, :active] => :finished
             end
 
             event :failure do
-              transition [:failed, :finalizing, :active] => :failed
+              transition [:failed, :active] => :failed
             end
 
             event :hold do
               transition any => :paused
             end
 
+            event :execute do
+              transition any => :active
+            end
+
             before_transition any => [:paused] do |worker|
               worker.on_hold_until = RETRY_DELAY.from_now
 
@@ -114,6 +115,14 @@ module Gitlab
                 duration_s: RETRY_DELAY.to_i
               )
             end
+
+            before_transition any => :finished do |migration|
+              migration.finished_at = Time.current
+            end
+
+            before_transition any => :active do |migration|
+              migration.started_at = Time.current
+            end
           end
 
           def job_class
@@ -132,15 +141,18 @@ module Gitlab
           end
 
           def create_job!(min, max)
-            jobs.create!(
+            args = {
               batch_size: batch_size,
               sub_batch_size: sub_batch_size,
               pause_ms: pause_ms,
               min_cursor: min,
               max_cursor: max,
-              worker_partition: partition,
-              organization_id: organization_id
-            )
+              worker_partition: partition
+            }
+
+            args[:organization_id] = organization_id if respond_to?(:organization_id)
+
+            jobs.create!(args)
           end
 
           # Returns the end cursor of the last batch as the starting point for the next batch.
@@ -150,6 +162,13 @@ module Gitlab
             last_job&.max_cursor || min_cursor
           end
 
+          def interval_elapsed?(variance: 0)
+            return true unless last_job
+
+            interval_with_variance = interval - variance
+            last_job.created_at <= Time.current - interval_with_variance
+          end
+
           def health_context
             Gitlab::Database::HealthStatus::Context.new(
               self,
@@ -199,13 +218,14 @@ module Gitlab
         end
 
         class_methods do
-          def schedulable_workers(limit)
+          def schedulable_workers(connection, limit)
             unions = Gitlab::Database::PostgresPartitionedTable.each_partition(table_name).map do |partition|
               partition_name = partition.name
 
               select('id, partition, created_at')
                 .from("#{Gitlab::Database::DYNAMIC_PARTITIONS_SCHEMA}.#{partition_name} AS #{table_name}")
                 .executable
+                .for_gitlab_schema(Gitlab::Database.gitlab_schemas_for_connection(connection))
                 .order(created_at: :asc)
                 .limit(limit)
             end
