@@ -686,13 +686,14 @@ module Gitlab
         end
       end
 
-      def merge(user, source_sha:, target_branch:, message:, target_sha: nil, &block)
+      def merge(user, source_sha:, target_branch:, message:, target_sha: nil, sign: true, &block)
         wrapped_gitaly_errors do
           gitaly_operation_client.user_merge_branch(user,
             source_sha: source_sha,
             target_branch: target_branch,
             message: message,
             target_sha: target_sha,
+            sign: sign,
             &block)
         end
       end
@@ -706,7 +707,8 @@ module Gitlab
         end
       end
 
-      def revert(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:, dry_run: false, target_sha: nil)
+      # rubocop:disable Metrics/ParameterLists -- all arguments needed
+      def revert(user:, commit:, branch_name:, message:, start_branch_name:, start_repository:, dry_run: false, target_sha: nil, sign: true)
         args = {
           user: user,
           commit: commit,
@@ -715,13 +717,15 @@ module Gitlab
           start_branch_name: start_branch_name,
           start_repository: start_repository,
           dry_run: dry_run,
-          target_sha: target_sha
+          target_sha: target_sha,
+          sign: sign
         }
 
         wrapped_gitaly_errors do
           gitaly_operation_client.user_revert(**args)
         end
       end
+      # rubocop:enable Metrics/ParameterLists
 
       def cherry_pick(...)
         wrapped_gitaly_errors do
@@ -992,9 +996,9 @@ module Gitlab
         end
       end
 
-      def squash(user, start_sha:, end_sha:, author:, message:)
+      def squash(user, start_sha:, end_sha:, author:, message:, sign: true)
         wrapped_gitaly_errors do
-          gitaly_operation_client.user_squash(user, start_sha, end_sha, author, message)
+          gitaly_operation_client.user_squash(user, start_sha: start_sha, end_sha: end_sha, author: author, message: message, sign: sign)
         end
       end
 
