@@ -19,10 +19,11 @@ module Gitlab
     end
 
     # Returns the ID of the ghost user.
-    def self.ghost_user_id
-      key = 'github-import/ghost-user-id'
+    def self.ghost_user_id(organization_id)
+      key = "github-import/ghost-user-id/#{organization_id}"
 
-      Gitlab::Cache::Import::Caching.read_integer(key) || Gitlab::Cache::Import::Caching.write(key, Users::Internal.ghost.id)
+      Gitlab::Cache::Import::Caching.read_integer(key) ||
+        Gitlab::Cache::Import::Caching.write(key, Users::Internal.in_organization(organization_id).ghost.id)
     end
 
     # Get formatted GitHub import URL. If github.com is in the import URL, this will return nil and octokit will use the default github.com API URL
