@@ -22,6 +22,8 @@ module Gitlab
       gon.math_rendering_limits_enabled = Gitlab::CurrentSettings.math_rendering_limits_enabled
       gon.allow_immediate_namespaces_deletion =
         Gitlab::CurrentSettings.allow_immediate_namespaces_deletion_for_user?(current_user)
+      gon.iframe_rendering_enabled      = Gitlab::CurrentSettings.iframe_rendering_enabled?
+      gon.iframe_rendering_allowlist    = Gitlab::CurrentSettings.iframe_rendering_allowlist
 
       # Sentry configurations for the browser client are done
       # via `Gitlab::CurrentSettings` from the Admin panel:
@@ -99,18 +101,16 @@ module Gitlab
       push_frontend_feature_flag(:find_and_replace, current_user)
       # To be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/399248
       push_frontend_feature_flag(:remove_monitor_metrics)
-      push_frontend_feature_flag(:work_item_view_for_issues)
       push_frontend_feature_flag(:new_project_creation_form, current_user, type: :wip)
       push_frontend_feature_flag(:work_items_client_side_boards, current_user)
       push_frontend_feature_flag(:glql_work_items, current_user)
       push_frontend_feature_flag(:glql_aggregation, current_user, type: :wip)
       push_frontend_feature_flag(:glql_typescript, current_user, type: :wip)
-      push_frontend_feature_flag(:paneled_view, current_user)
       push_frontend_feature_flag(:archive_group)
       push_frontend_feature_flag(:accessible_loading_button, current_user)
 
       # Expose the Project Studio user preference as if it were a feature flag
-      push_force_frontend_feature_flag(:project_studio_enabled, Users::ProjectStudio.new(current_user).enabled?)
+      push_force_frontend_feature_flag(:project_studio_enabled, true)
     end
 
     # Exposes the state of a feature flag to the frontend code.
@@ -143,6 +143,12 @@ module Gitlab
       push_to_gon_attributes(:features, name, enabled)
     end
 
+    def push_application_setting(key)
+      return unless Gitlab::CurrentSettings.respond_to?(key)
+
+      gon.push({ key => Gitlab::CurrentSettings.public_send(key) }) # rubocop:disable GitlabSecurity/PublicSend
+    end
+
     def push_namespace_setting(key, object)
       return unless object&.namespace_settings.respond_to?(key)
 
