@@ -6,10 +6,12 @@ module Gitlab
       class RelationFactory < Base::RelationFactory
         OVERRIDES = {
           labels: :group_labels,
-          priorities: :label_priorities,
           label: :group_label,
           parent: :epic,
-          iterations_cadences: 'Iterations::Cadence'
+          iterations_cadences: 'Iterations::Cadence',
+          user_contributions: :user,
+          epic_lists: 'Boards::EpicList',
+          epic_boards: 'Boards::EpicBoard'
         }.freeze
 
         EXISTING_OBJECT_RELATIONS = %i[
@@ -21,6 +23,19 @@ module Gitlab
           labels
           group_label
           group_labels
+          iteration
+          iterations
+        ].freeze
+
+        RELATIONS_WITH_REWRITABLE_USERNAMES = %i[
+          milestone
+          milestones
+          epic
+          epics
+          release
+          releases
+          note
+          notes
         ].freeze
 
         private
@@ -29,9 +44,14 @@ module Gitlab
           case @relation_name
           when :notes then setup_note
           when :'Iterations::Cadence' then setup_iterations_cadence
+          when :events then setup_event
           end
 
           update_group_references
+
+          return unless RELATIONS_WITH_REWRITABLE_USERNAMES.include?(@relation_name) && @rewrite_mentions
+
+          update_username_mentions(@relation_hash)
         end
 
         def invalid_relation?
@@ -52,6 +72,10 @@ module Gitlab
         def setup_iterations_cadence
           @relation_hash['automatic'] = false
         end
+
+        def setup_event
+          @relation_hash = {} if @relation_hash['author_id'].nil?
+        end
       end
     end
   end
