@@ -251,7 +251,8 @@ module Gitlab
     def self.convert_to_time(time_value)
       return time_value if time_value.is_a?(Time)
       return Time.iso8601(time_value) if time_value.is_a?(String)
-      return Time.at(time_value) if time_value.is_a?(Numeric) && time_value > 0
+
+      Time.at(time_value) if time_value.is_a?(Numeric) && time_value > 0
     rescue ArgumentError
       # Swallow invalid dates. Better to loose some observability
       # than bring all background processing down because of a date
