@@ -64,12 +64,12 @@ module Gitlab
         end
 
         def search_scopes
-          Gitlab::Search::AbuseDetection::ALLOWED_SCOPES
+          ::Search::Scopes.all_scope_names
         end
 
         def endpoint_ids
           api_endpoints = ['GET /api/:version/search', 'GET /api/:version/projects/:id/(-/)search',
-                           'GET /api/:version/groups/:id/(-/)search']
+            'GET /api/:version/groups/:id/(-/)search']
           web_endpoints = ['SearchController#show']
 
           endpoints = []
