@@ -19,15 +19,15 @@ module Gitlab
         # /merge
         #
         desc do
-          if preferred_strategy = preferred_auto_merge_strategy(quick_action_target)
-            _("Merge automatically (%{strategy})") % { strategy: preferred_strategy.humanize }
+          if strategy = preferred_auto_merge_strategy(quick_action_target)
+            auto_merge_strategy_copy(strategy, :desc)
           else
             _("Merge immediately")
           end
         end
         explanation do
-          if preferred_strategy = preferred_auto_merge_strategy(quick_action_target)
-            _("Schedules to merge this merge request (%{strategy}).") % { strategy: preferred_strategy.humanize }
+          if strategy = preferred_auto_merge_strategy(quick_action_target)
+            auto_merge_strategy_copy(strategy, :explanation)
           else
             _('Merges this merge request immediately.')
           end
@@ -37,8 +37,8 @@ module Gitlab
             _("The `/merge` quick action requires the SHA of the head of the branch.")
           elsif params[:merge_request_diff_head_sha] != quick_action_target.diff_head_sha
             _("Branch has been updated since the merge was requested.")
-          elsif preferred_strategy = preferred_auto_merge_strategy(quick_action_target)
-            _("Scheduled to merge this merge request (%{strategy}).") % { strategy: preferred_strategy.humanize }
+          elsif strategy = preferred_auto_merge_strategy(quick_action_target)
+            auto_merge_strategy_copy(strategy, :feedback)
           else
             _('Merged this merge request.')
           end
@@ -194,6 +194,7 @@ module Gitlab
         command :submit_review do |state = "reviewed"|
           next if params[:review_id]
 
+          pending_comments_count = quick_action_target.draft_notes.authored_by(current_user).count
           result = DraftNotes::PublishService.new(quick_action_target, current_user).execute
 
           reviewer_state = state.strip.presence
@@ -204,6 +205,12 @@ module Gitlab
                                                  [result[:message]]
                                                end
 
+          @additional_properties[:submit_review] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s,
+            pending_comments: pending_comments_count,
+            state: reviewer_state
+          }
+
           if reviewer_state === 'approve'
             approval_success = ::MergeRequests::ApprovalService
               .new(project: quick_action_target.project, current_user: current_user)
@@ -254,9 +261,11 @@ module Gitlab
           quick_action_target.persisted? && quick_action_target.eligible_for_approval_by?(current_user) && !quick_action_target.merged?
         end
         command :approve do
+          pending_comments_count = quick_action_target.draft_notes.authored_by(current_user).count
+
           @execution_message[:approve] = []
 
-          if quick_action_target.draft_notes.authored_by(current_user).any? && params[:review_id].blank?
+          if pending_comments_count > 0 && params[:review_id].blank?
             result = DraftNotes::PublishService.new(quick_action_target, current_user).execute
 
             @execution_message[:approve] = if result[:status] == :success
@@ -270,6 +279,11 @@ module Gitlab
 
           next unless success
 
+          @additional_properties[:approve] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s,
+            pending_comments: pending_comments_count
+          }
+
           @execution_message[:approve] << _('Approved the current merge request.')
         end
 
@@ -288,6 +302,10 @@ module Gitlab
 
           next unless success
 
+          @additional_properties[:unapprove] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s
+          }
+
           @execution_message[:unapprove] = _('Unapproved the current merge request.')
         end
 
@@ -491,6 +509,18 @@ module Gitlab
 
           @execution_message[:ship] = _('Actions to ship this merge request have been scheduled.')
         end
+
+        desc { _('Run a pipeline') }
+        explanation { _('Run a new pipeline for this merge request') }
+        types MergeRequest
+        condition do
+          create_pipeline_service.allowed?(quick_action_target)
+        end
+        command :run_pipeline do
+          create_pipeline_service.execute_async(quick_action_target)
+
+          @execution_message[:run_pipeline] = _('New pipeline has been triggered and will appear shortly.')
+        end
       end
 
       def reviewer_users_sentence(users)
@@ -529,10 +559,25 @@ module Gitlab
         quick_action_target.reviewers.any? || updates&.dig(:reviewer_ids)&.any?
       end
 
+      def auto_merge_strategy_copy(_strategy, type)
+        case type
+        when :desc then _('Set to auto-merge')
+        when :explanation then _('Sets this merge request to auto-merge when ready.')
+        when :feedback then _('Set to auto-merge.')
+        end
+      end
+
       def merge_orchestration_service
         @merge_orchestration_service ||= ::MergeRequests::MergeOrchestrationService.new(project, current_user)
       end
 
+      def create_pipeline_service
+        @create_pipeline_service ||= ::MergeRequests::CreatePipelineService.new(
+          project: quick_action_target.project,
+          current_user: current_user,
+          params: { allow_duplicate: true })
+      end
+
       def preferred_auto_merge_strategy(merge_request)
         merge_orchestration_service.preferred_auto_merge_strategy(merge_request)
       end
