@@ -116,6 +116,7 @@ module Gitlab
       def throttle_authenticated_web?
         (web_request? || frontend_request?) &&
           !throttle_authenticated_git_lfs? &&
+          !(git_path? && !git_lfs_path?) &&
           Gitlab::Throttle.settings.throttle_authenticated_web_enabled
       end
 
@@ -181,7 +182,7 @@ module Gitlab
       end
 
       def throttle_authenticated_git_http?
-        git_path? &&
+        git_path? && !git_lfs_path? &&
           Gitlab::Throttle.settings.throttle_authenticated_git_http_enabled
       end
 
