@@ -248,16 +248,6 @@ module Gitlab
                 "DastProfiles|A selector describing the element used to enter the username on the login form."
               )
             },
-            DAST_CRAWL_EXTRACT_ELEMENT_TIMEOUT: {
-              additional: true,
-              type: "Duration string",
-              example: "5s",
-              name: s_("DastProfiles|Extract element timeout"),
-              description: s_(
-                "DastProfiles|The maximum amount of time to allow the browser to extract newly found elements " \
-                  "or navigations. Defaults to `5s`."
-              )
-            },
             DAST_CRAWL_MAX_ACTIONS: {
               additional: true,
               type: "number",
@@ -280,16 +270,6 @@ module Gitlab
                   "Defaults to `10`."
               )
             },
-            DAST_CRAWL_SEARCH_ELEMENT_TIMEOUT: {
-              additional: true,
-              type: "Duration string",
-              example: "3s",
-              name: s_("DastProfiles|Element search timeout"),
-              description: s_(
-                "DastProfiles|The maximum amount of time to allow the browser to search for new elements " \
-                  "or user actions. Defaults to `3s`."
-              )
-            },
             DAST_CRAWL_TIMEOUT: {
               additional: true,
               type: "Duration string",
@@ -652,7 +632,8 @@ module Gitlab
               example: "brows:debug,auth:debug",
               name: s_("DastProfiles|Log levels"),
               description: s_(
-                "DastProfiles|A list of modules and their intended logging level for use in the console log.")
+                "DastProfiles|(Deprecated) A list of modules and their intended logging level " \
+                  "for use in the console log.")
             },
             DAST_LOG_DEVTOOLS_CONFIG: {
               additional: true,
