@@ -31,7 +31,8 @@ module Gitlab
             sidekiq_elasticsearch_requests_total: ::Gitlab::Metrics.counter(:sidekiq_elasticsearch_requests_total, 'Elasticsearch requests during a Sidekiq job execution'),
             sidekiq_running_jobs: ::Gitlab::Metrics.gauge(:sidekiq_running_jobs, 'Number of Sidekiq jobs running', {}, :all),
             sidekiq_concurrency: ::Gitlab::Metrics.gauge(:sidekiq_concurrency, 'Maximum number of Sidekiq jobs', {}, :all),
-            sidekiq_mem_total_bytes: ::Gitlab::Metrics.gauge(:sidekiq_mem_total_bytes, 'Number of bytes allocated for both objects consuming an object slot and objects that required a malloc', {}, :all)
+            sidekiq_mem_total_bytes: ::Gitlab::Metrics.gauge(:sidekiq_mem_total_bytes, 'Number of bytes allocated for both objects consuming an object slot and objects that required a malloc', {}, :all),
+            sidekiq_gvl_measurement_enabled: ::Gitlab::Metrics.gauge(:sidekiq_gvl_measurement_enabled, 'Indicates whether GVL Tools instrumentation is enabled', {}, :all)
           }
 
           if Feature.enabled?(:emit_sidekiq_histogram_metrics, type: :ops)
@@ -134,6 +135,11 @@ module Gitlab
         @job_succeeded = false
         monotonic_time_start = Gitlab::Metrics::System.monotonic_time
         job_thread_cputime_start = get_thread_cputime
+
+        ensure_gvltools!
+        gvl_local_time_start = GVLTools::LocalTimer.monotonic_time
+        gvl_global_time_start = GVLTools::GlobalTimer.monotonic_time
+
         begin
           transaction = Gitlab::Metrics::BackgroundTransaction.new
           transaction.run { yield }
@@ -146,6 +152,8 @@ module Gitlab
 
           @monotonic_time = monotonic_time_end - monotonic_time_start
           @job_thread_cputime = job_thread_cputime_end - job_thread_cputime_start
+          @gvl_local_time = (GVLTools::LocalTimer.monotonic_time - gvl_local_time_start) / 1_000_000_000.0
+          @gvl_global_time = (GVLTools::GlobalTimer.monotonic_time - gvl_global_time_start) / 1_000_000_000.0
 
           @metrics[:sidekiq_running_jobs].increment(labels, -1)
 
@@ -175,6 +183,7 @@ module Gitlab
           record_execution_sli unless e.is_a?(Gitlab::SidekiqMiddleware::RetryError)
           record_queueing_sli
           record_db_txn_sli if Feature.enabled?(:emit_db_transaction_sli_metrics, type: :ops)
+          record_gvl_measurements
         end
       end
 
@@ -224,6 +233,30 @@ module Gitlab
         end
       end
 
+      def record_gvl_measurements
+        @metrics[:sidekiq_gvl_measurement_enabled].set(labels, gvl_tools_enabled? ? 1 : 0)
+        return unless gvl_tools_enabled?
+
+        unless @metrics[:sidekiq_gvl_thread_wait_seconds]
+          @metrics[:sidekiq_gvl_thread_wait_seconds] = ::Gitlab::Metrics.histogram(
+            :sidekiq_gvl_thread_wait_seconds,
+            'Seconds of this thread waiting for GVL',
+            {},
+            SIDEKIQ_LATENCY_BUCKETS)
+        end
+
+        unless @metrics[:sidekiq_gvl_process_wait_seconds]
+          @metrics[:sidekiq_gvl_process_wait_seconds] = ::Gitlab::Metrics.gauge(
+            :sidekiq_gvl_process_wait_seconds,
+            'Seconds of this process waiting for GVL',
+            {},
+            :all)
+        end
+
+        @metrics[:sidekiq_gvl_thread_wait_seconds].observe(labels, @gvl_local_time)
+        @metrics[:sidekiq_gvl_process_wait_seconds].increment(labels, @gvl_global_time)
+      end
+
       def with_load_balancing_settings(job)
         keys = %w[load_balancing_strategy worker_data_consistency]
         return unless keys.all? { |k| job.key?(k) }
@@ -258,6 +291,21 @@ module Gitlab
       def get_gitaly_time(payload)
         payload.fetch(:gitaly_duration_s, 0)
       end
+
+      def ensure_gvltools!
+        # Enabling GVLTools incurs some overhead, so we ensure it's only enabled when the FF is enabled too.
+        if gvl_tools_enabled?
+          GVLTools::LocalTimer.enable
+          GVLTools::GlobalTimer.enable
+        else
+          GVLTools::LocalTimer.disable
+          GVLTools::GlobalTimer.disable
+        end
+      end
+
+      def gvl_tools_enabled?
+        Feature.enabled?(:enable_sidekiq_gvl_metrics, :current_pod, type: :ops)
+      end
     end
   end
 end
