@@ -3,8 +3,8 @@
 module Tasks
   module Gitlab
     module Permissions
-      class ValidateTask
-        PERMISSION_DIR = 'config/authz/permissions'
+      class ValidateTask < ::Tasks::Gitlab::Permissions::BaseValidateTask
+        PERMISSION_DIR = ::Authz::Permission::BASE_PATH
         PERMISSION_TODO_FILE = "#{PERMISSION_DIR}/definitions_todo.txt".freeze
         JSON_SCHEMA_FILE = 'config/authz/permissions/type_schema.json'
         PERMISSION_NAME_REGEX = /\A[a-z]+_[a-z_]+[a-z]\z/
@@ -21,20 +21,6 @@ module Tasks
           view: 'read'
         }.freeze
 
-        ERROR_MESSAGES = {
-          definition: "The following permissions are missing a definition file." \
-            "\nRun bundle exec rails generate authz:permission <NAME> to generate definition files.",
-          excluded: "The following permissions have a definition file." \
-            "\nRemove them from config/authz/permissions/definitions_todo.txt.",
-          schema: "The following permissions failed schema validation.",
-          action: "The following permissions contain a disallowed action.",
-          name: "The following permissions have invalid names." \
-            "\nPermission name must be in the format action_resource[_subresource].",
-          file: "The following permission definitions do not exist at the expected path.",
-          unknown_permission: "The following permissions have a definition file but are not found in " \
-            "declarative policy.\nRemove the definition files for the unkonwn permissions."
-        }.freeze
-
         attr_reader :declarative_policy_permissions
 
         def initialize
@@ -45,20 +31,25 @@ module Tasks
             action: {},
             name: [],
             file: {},
-            unknown_permission: []
+            unknown_permission: [],
+            missing_resource_metadata: [],
+            resource_metadata_schema: {}
           }
           @declarative_policy_permissions = load_declarative_policy_permissions
-        end
-
-        def run
-          validate!
-
-          puts "Permission definitions are up-to-date"
+          @resources = []
         end
 
         private
 
-        attr_reader :violations
+        attr_reader :violations, :resources
+
+        def validate!
+          declarative_policy_permissions.each { |permission| validate_permission(permission) }
+          validate_unknown_permissions
+          validate_resources
+
+          super
+        end
 
         def load_declarative_policy_permissions
           require_policy_files
@@ -72,87 +63,6 @@ module Tasks
           permissions.sort.uniq
         end
 
-        def validate!
-          declarative_policy_permissions.each { |permission| validate_permission(permission) }
-          validate_unknown_permissions
-
-          abort_if_errors_found!
-        end
-
-        def abort_if_errors_found!
-          return if violations.all? { |_, v| v.empty? }
-
-          print_errors
-
-          abort
-        end
-
-        def print_errors
-          out = format_error_list(:definition)
-          out += format_error_list(:excluded)
-          out += format_schema_errors
-          out += format_error_list(:name)
-          out += format_action_errors
-          out += format_file_errors
-          out += format_error_list(:unknown_permission)
-
-          puts "#######################################################################\n#"
-          puts out.gsub(/^/, '#  ').gsub(/\s+$/, '')
-          puts "#######################################################################"
-        end
-
-        def format_error_list(kind)
-          return '' if violations[kind].empty?
-
-          out = "#{ERROR_MESSAGES[kind]}\n\n"
-
-          violations[kind].each do |permission|
-            out += "  - #{permission}\n"
-          end
-
-          "#{out}\n"
-        end
-
-        def format_schema_errors
-          return '' if violations[:schema].empty?
-
-          out = "#{ERROR_MESSAGES[:schema]}\n\n"
-
-          violations[:schema].each_key do |permission|
-            out += "  - #{permission}\n"
-            violations[:schema][permission].each { |error| out += "      - #{JSONSchemer::Errors.pretty(error)}\n" }
-          end
-
-          "#{out}\n"
-        end
-
-        def format_action_errors
-          return '' if violations[:action].empty?
-
-          out = "#{ERROR_MESSAGES[:action]}\n\n"
-
-          violations[:action].each_key do |permission|
-            action = violations[:action][permission]
-            preferred = DISALLOWED_ACTIONS[action]
-
-            out += "  - #{permission}: Prefer #{preferred} over #{action}.\n"
-          end
-
-          "#{out}\n"
-        end
-
-        def format_file_errors
-          return '' if violations[:file].empty?
-
-          out = "#{ERROR_MESSAGES[:file]}\n"
-
-          violations[:file].each do |permission, expected_path|
-            out += "\n  - Name: #{permission}\n    Expected Path: #{expected_path}\n"
-          end
-
-          "#{out}\n"
-        end
-
         def require_policy_files
           Dir["./app/policies/**/*.rb"].each { |file| require file }
           Dir["./ee/app/policies/**/*.rb"].each { |file| require file }
@@ -172,11 +82,8 @@ module Tasks
           validate_name(permission)
           validate_action(permission)
           validate_file(permission)
-        end
 
-        def validate_schema(permission)
-          errors = schema_validator.validate(permission.definition)
-          violations[:schema][permission.name] = errors if errors.any?
+          @resources << permission.resource
         end
 
         def validate_action(permission)
@@ -192,13 +99,33 @@ module Tasks
         end
 
         def validate_file(permission)
-          # No need to check the file path with an invalid name
-          return unless permission.action && permission.resource
+          source_file = permission.source_file
+          actual_path = source_file[source_file.index(PERMISSION_DIR)..]
+          name = "#{permission.name} in #{actual_path}"
 
-          expected_file = "#{PERMISSION_DIR}/#{permission.resource}/#{permission.action}.yml"
-          return if permission.source_file.ends_with?(expected_file)
+          # ensure file is under a resource directory and has a name
+          unless permission.resource.present? && permission.action.present?
+            expected_action = permission.action.presence || '<action>'
+            expected_resource = permission.resource.presence || '<resource>'
+            expected_path = "#{PERMISSION_DIR}/#{expected_resource}/#{expected_action}.yml"
+            violations[:file][name] = "Expected path: #{expected_path}"
+            return
+          end
 
-          violations[:file][permission.name] = expected_file
+          # ensure there are no extra directories between PERMISSION_DIR and <resource>/<action>.yml
+          expected_path = "#{PERMISSION_DIR}/#{permission.resource}/#{permission.action}.yml"
+          unless expected_path == actual_path
+            violations[:file][name] = "Expected path: #{expected_path}"
+            return
+          end
+
+          # ensure resource and action based on the path matches name field value
+          name_from_path = "#{permission.action}_#{permission.resource}"
+          return if name_from_path == permission.name
+
+          violations[:file][name] =
+            "Path must match '#{PERMISSION_DIR}/<resource>/<action>.yml' based on <resource> and <action> values " \
+              "from '#{permission.name}' ('<action>_<resource>')"
         end
 
         def validate_unknown_permissions
@@ -206,6 +133,50 @@ module Tasks
           violations[:unknown_permission] = defined_permissions - declarative_policy_permissions
         end
 
+        def validate_resources
+          resources.compact_blank.uniq.each do |name|
+            resource = ::Authz::Resource.get(name)
+
+            unless resource
+              violations[:missing_resource_metadata] << "#{::Authz::Permission::BASE_PATH}/**/#{name}/"
+              next
+            end
+
+            @resource_metadata_schema_validator ||= JSONSchemer.schema(
+              Rails.root.join("#{PERMISSION_DIR}/resource_metadata_schema.json")
+            )
+            errors = @resource_metadata_schema_validator.validate(resource.definition)
+            violations[:resource_metadata_schema][name] = errors if errors.any?
+          end
+        end
+
+        def format_all_errors
+          out = format_error_list(:definition)
+          out += format_error_list(:excluded)
+          out += format_schema_errors
+          out += format_error_list(:name)
+          out += format_action_errors
+          out += format_file_errors
+          out += format_error_list(:unknown_permission)
+          out += format_error_list(:missing_resource_metadata)
+          out + format_schema_errors(:resource_metadata_schema)
+        end
+
+        def format_action_errors
+          return '' if violations[:action].empty?
+
+          out = "#{error_messages[:action]}\n\n"
+
+          violations[:action].each_key do |permission|
+            action = violations[:action][permission]
+            preferred = DISALLOWED_ACTIONS[action]
+
+            out += "  - #{permission}: Prefer #{preferred} over #{action}.\n"
+          end
+
+          "#{out}\n"
+        end
+
         def exclusion_list
           @excludes ||= if File.exist?(exclusion_file)
                           File.read(exclusion_file).split("\n").reject(&:empty?).map { |p| p.strip.to_sym }
@@ -218,8 +189,27 @@ module Tasks
           Rails.root.join(PERMISSION_TODO_FILE)
         end
 
-        def schema_validator
-          @schema_validator ||= JSONSchemer.schema(Rails.root.join(JSON_SCHEMA_FILE))
+        def error_messages
+          {
+            definition: "The following permissions are missing a definition file." \
+              "\nRun bundle exec rails generate authz:permission <NAME> to generate definition files.",
+            excluded: "The following permissions have a definition file." \
+              "\nRemove them from config/authz/permissions/definitions_todo.txt.",
+            schema: "The following permissions failed schema validation.",
+            action: "The following permissions contain a disallowed action.",
+            name: "The following permissions have invalid names." \
+              "\nPermission name must be in the format action_resource[_subresource].",
+            file: "The following permission definitions do not exist at the expected path.",
+            unknown_permission: "The following permissions have a definition file but are not found in " \
+              "declarative policy.\nRemove the definition files for the unknown permissions.",
+            missing_resource_metadata:
+              "The following permission resource directories are missing a _metadata.yml file.",
+            resource_metadata_schema: "The following resource metadata files failed schema validation."
+          }
+        end
+
+        def json_schema_file
+          Rails.root.join("#{PERMISSION_DIR}/type_schema.json")
         end
       end
     end
