@@ -30,11 +30,18 @@ module Tooling
           render_row(
             "`#{key}`",
             render_type(variable[:type]),
-            "`#{variable[:example]}`",
+            render_example(variable[:example]),
             render_description(variable[:description])
           )
         end
 
+        def render_example(example)
+          case example
+          when nil then ''
+          else "`#{example}`"
+          end
+        end
+
         def render_type(type)
           case type
           when 'Duration string' then '[Duration string](https://pkg.go.dev/time#ParseDuration)'
